# ACT I

### PROLOGUE

_Enter GOWER_

_Before the palace of Antioch_

**GOWER**  
To sing a song that old was sung,  
From ashes ancient Gower is come;  
Assuming man's infirmities,  
To glad your ear, and please your eyes.  
It hath been sung at festivals,  
On ember-eves and holy-ales;  
And lords and ladies in their lives  
Have read it for restoratives:  
The purchase is to make men glorious;  
Et bonum quo antiquius, eo melius.  
If you, born in these latter times,  
When wit's more ripe, accept my rhymes.  
And that to hear an old man sing  
May to your wishes pleasure bring  
I life would wish, and that I might  
Waste it for you, like taper-light.  
This Antioch, then, Antiochus the Great  
Built up, this city, for his chiefest seat:  
The fairest in all Syria,  
I tell you what mine authors say:  
This king unto him took a fere,  
Who died and left a female heir,  
So buxom, blithe, and full of face,  
As heaven had lent her all his grace;  
With whom the father liking took,  
And her to incest did provoke:  
Bad child; worse father! to entice his own  
To evil should be done by none:  
But custom what they did begin  
Was with long use account no sin.  
The beauty of this sinful dame  
Made many princes thither frame,  
To seek her as a bed-fellow,  
In marriage-pleasures play-fellow:  
Which to prevent he made a law,  
To keep her still, and men in awe,  
That whoso ask'd her for his wife,  
His riddle told not, lost his life:  
So for her many a wight did die,  
As yon grim looks do testify.  
What now ensues, to the judgment of your eye  
I give, my cause who best can justify.  

_Exit_

### SCENE I. Antioch. A room in the palace.

_Enter ANTIOCHUS, Prince PERICLES, and followers_

**ANTIOCHUS**  
Young prince of Tyre, you have at large received  
The danger of the task you undertake.  

**PERICLES**  
I have, Antiochus, and, with a soul  
Embolden'd with the glory of her praise,  
Think death no hazard in this enterprise.  

**ANTIOCHUS**  
Bring in our daughter, clothed like a bride,  
For the embracements even of Jove himself;  
At whose conception, till Lucina reign'd,  
Nature this dowry gave, to glad her presence,  
The senate-house of planets all did sit,  
To knit in her their best perfections.  

_Music. Enter the Daughter of ANTIOCHUS_

**PERICLES**  
See where she comes, apparell'd like the spring,  
Graces her subjects, and her thoughts the king  
Of every virtue gives renown to men!  
Her face the book of praises, where is read  
Nothing but curious pleasures, as from thence  
Sorrow were ever razed and testy wrath  
Could never be her mild companion.  
You gods that made me man, and sway in love,  
That have inflamed desire in my breast  
To taste the fruit of yon celestial tree,  
Or die in the adventure, be my helps,  
As I am son and servant to your will,  
To compass such a boundless happiness!  

**ANTIOCHUS**  
Prince Pericles,--  

**PERICLES**  
That would be son to great Antiochus.  

**ANTIOCHUS**  
Before thee stands this fair Hesperides,  
With golden fruit, but dangerous to be touch'd;  
For death-like dragons here affright thee hard:  
Her face, like heaven, enticeth thee to view  
Her countless glory, which desert must gain;  
And which, without desert, because thine eye  
Presumes to reach, all thy whole heap must die.  
Yon sometimes famous princes, like thyself,  
Drawn by report, adventurous by desire,  
Tell thee, with speechless tongues and semblance pale,  
That without covering, save yon field of stars,  
Here they stand martyrs, slain in Cupid's wars;  
And with dead cheeks advise thee to desist  
For going on death's net, whom none resist.  

**PERICLES**  
Antiochus, I thank thee, who hath taught  
My frail mortality to know itself,  
And by those fearful objects to prepare  
This body, like to them, to what I must;  
For death remember'd should be like a mirror,  
Who tells us life's but breath, to trust it error.  
I'll make my will then, and, as sick men do  
Who know the world, see heaven, but, feeling woe,  
Gripe not at earthly joys as erst they did;  
So I bequeath a happy peace to you  
And all good men, as every prince should do;  
My riches to the earth from whence they came;  
But my unspotted fire of love to you.  

_To the Daughter of ANTIOCHUS_

Thus ready for the way of life or death,  
I wait the sharpest blow, Antiochus.  

**ANTIOCHUS**  
Scorning advice, read the conclusion then:  
Which read and not expounded, 'tis decreed,  
As these before thee thou thyself shalt bleed.  

**Daughter**  
Of all say'd yet, mayst thou prove prosperous!  
Of all say'd yet, I wish thee happiness!  

**PERICLES**  
Like a bold champion, I assume the lists,  
Nor ask advice of any other thought  
But faithfulness and courage.  

_He reads the riddle_

I am no viper, yet I feed  
On mother's flesh which did me breed.  
I sought a husband, in which labour  
I found that kindness in a father:  
He's father, son, and husband mild;  
I mother, wife, and yet his child.  
How they may be, and yet in two,  
As you will live, resolve it you.  
Sharp physic is the last: but, O you powers  
That give heaven countless eyes to view men's acts,  
Why cloud they not their sights perpetually,  
If this be true, which makes me pale to read it?  
Fair glass of light, I loved you, and could still,  

_Takes hold of the hand of the Daughter of ANTIOCHUS_

Were not this glorious casket stored with ill:  
But I must tell you, now my thoughts revolt  
For he's no man on whom perfections wait  
That, knowing sin within, will touch the gate.  
You are a fair viol, and your sense the strings;  
Who, finger'd to make man his lawful music,  
Would draw heaven down, and all the gods, to hearken:  
But being play'd upon before your time,  
Hell only danceth at so harsh a chime.  
Good sooth, I care not for you.  

**ANTIOCHUS**  
Prince Pericles, touch not, upon thy life.  
For that's an article within our law,  
As dangerous as the rest. Your time's expired:  
Either expound now, or receive your sentence.  

**PERICLES**  
Great king,  
Few love to hear the sins they love to act;  
'Twould braid yourself too near for me to tell it.  
Who has a book of all that monarchs do,  
He's more secure to keep it shut than shown:  
For vice repeated is like the wandering wind.  
Blows dust in other's eyes, to spread itself;  
And yet the end of all is bought thus dear,  
The breath is gone, and the sore eyes see clear:  
To stop the air would hurt them. The blind mole casts  
Copp'd hills towards heaven, to tell the earth is throng'd  
By man's oppression; and the poor worm doth die for't.  
Kings are earth's gods; in vice their law's  
their will;  
And if Jove stray, who dares say Jove doth ill?  
It is enough you know; and it is fit,  
What being more known grows worse, to smother it.  
All love the womb that their first being bred,  
Then give my tongue like leave to love my head.  

**ANTIOCHUS**  
_[Aside]_  
Heaven, that I had thy head! he has found  
the meaning:  
But I will gloze with him.--Young prince of Tyre,  
Though by the tenor of our strict edict,  
Your exposition misinterpreting,  
We might proceed to cancel of your days;  
Yet hope, succeeding from so fair a tree  
As your fair self, doth tune us otherwise:  
Forty days longer we do respite you;  
If by which time our secret be undone,  
This mercy shows we'll joy in such a son:  
And until then your entertain shall be  
As doth befit our honour and your worth.  

_Exeunt all but PERICLES_

**PERICLES**  
How courtesy would seem to cover sin,  
When what is done is like an hypocrite,  
The which is good in nothing but in sight!  
If it be true that I interpret false,  
Then were it certain you were not so bad  
As with foul incest to abuse your soul;  
Where now you're both a father and a son,  
By your untimely claspings with your child,  
Which pleasure fits an husband, not a father;  
And she an eater of her mother's flesh,  
By the defiling of her parent's bed;  
And both like serpents are, who though they feed  
On sweetest flowers, yet they poison breed.  
Antioch, farewell! for wisdom sees, those men  
Blush not in actions blacker than the night,  
Will shun no course to keep them from the light.  
One sin, I know, another doth provoke;  
Murder's as near to lust as flame to smoke:  
Poison and treason are the hands of sin,  
Ay, and the targets, to put off the shame:  
Then, lest my lie be cropp'd to keep you clear,  
By flight I'll shun the danger which I fear.  

_Exit_

_Re-enter ANTIOCHUS_

**ANTIOCHUS**  
He hath found the meaning, for which we mean  
To have his head.  
He must not live to trumpet forth my infamy,  
Nor tell the world Antiochus doth sin  
In such a loathed manner;  
And therefore instantly this prince must die:  
For by his fall my honour must keep high.  
Who attends us there?  

_Enter THALIARD_

**THALIARD**  
Doth your highness call?  

**ANTIOCHUS**  
Thaliard,  
You are of our chamber, and our mind partakes  
Her private actions to your secrecy;  
And for your faithfulness we will advance you.  
Thaliard, behold, here's poison, and here's gold;  
We hate the prince of Tyre, and thou must kill him:  
It fits thee not to ask the reason why,  
Because we bid it. Say, is it done?  

**THALIARD**  
My lord,  
'Tis done.  

**ANTIOCHUS**  
Enough.  

_Enter a Messenger_

Let your breath cool yourself, telling your haste.  

**Messenger**  
My lord, prince Pericles is fled.  

_Exit_

**ANTIOCHUS**  
As thou  
Wilt live, fly after: and like an arrow shot  
From a well-experienced archer hits the mark  
His eye doth level at, so thou ne'er return  
Unless thou say 'Prince Pericles is dead.'  

**THALIARD**  
My lord,  
If I can get him within my pistol's length,  
I'll make him sure enough: so, farewell to your highness.  

**ANTIOCHUS**  
Thaliard, adieu!  

_Exit THALIARD_

Till Pericles be dead,  
My heart can lend no succor to my head.  

_Exit_

### SCENE II. Tyre. A room in the palace.

_Enter PERICLES_

**PERICLES**  
_[To Lords without]_  
Let none disturb us.--Why should  
this change of thoughts,  
The sad companion, dull-eyed melancholy,  
Be my so used a guest as not an hour,  
In the day's glorious walk, or peaceful night,  
The tomb where grief should sleep, can breed me quiet?  
Here pleasures court mine eyes, and mine eyes shun them,  
And danger, which I fear'd, is at Antioch,  
Whose aim seems far too short to hit me here:  
Yet neither pleasure's art can joy my spirits,  
Nor yet the other's distance comfort me.  
Then it is thus: the passions of the mind,  
That have their first conception by mis-dread,  
Have after-nourishment and life by care;  
And what was first but fear what might be done,  
Grows elder now and cares it be not done.  
And so with me: the great Antiochus,  
'Gainst whom I am too little to contend,  
Since he's so great can make his will his act,  
Will think me speaking, though I swear to silence;  
Nor boots it me to say I honour him.  
If he suspect I may dishonour him:  
And what may make him blush in being known,  
He'll stop the course by which it might be known;  
With hostile forces he'll o'erspread the land,  
And with the ostent of war will look so huge,  
Amazement shall drive courage from the state;  
Our men be vanquish'd ere they do resist,  
And subjects punish'd that ne'er thought offence:  
Which care of them, not pity of myself,  
Who am no more but as the tops of trees,  
Which fence the roots they grow by and defend them,  
Makes both my body pine and soul to languish,  
And punish that before that he would punish.  

_Enter HELICANUS, with other Lords_

**First Lord**  
Joy and all comfort in your sacred breast!  

**Second Lord**  
And keep your mind, till you return to us,  
Peaceful and comfortable!  

**HELICANUS**  
Peace, peace, and give experience tongue.  
They do abuse the king that flatter him:  
For flattery is the bellows blows up sin;  
The thing which is flatter'd, but a spark,  
To which that blast gives heat and stronger glowing;  
Whereas reproof, obedient and in order,  
Fits kings, as they are men, for they may err.  
When Signior Sooth here does proclaim a peace,  
He flatters you, makes war upon your life.  
Prince, pardon me, or strike me, if you please;  
I cannot be much lower than my knees.  

**PERICLES**  
All leave us else; but let your cares o'erlook  
What shipping and what lading's in our haven,  
And then return to us.  

_Exeunt Lords_

Helicanus, thou  
Hast moved us: what seest thou in our looks?  

**HELICANUS**  
An angry brow, dread lord.  

**PERICLES**  
If there be such a dart in princes' frowns,  
How durst thy tongue move anger to our face?  

**HELICANUS**  
How dare the plants look up to heaven, from whence  
They have their nourishment?  

**PERICLES**  
Thou know'st I have power  
To take thy life from thee.  

**HELICANUS**  
_[Kneeling]_  
I have ground the axe myself;  
Do you but strike the blow.  

**PERICLES**  
Rise, prithee, rise.  
Sit down: thou art no flatterer:  
I thank thee for it; and heaven forbid  
That kings should let their ears hear their  
faults hid!  
Fit counsellor and servant for a prince,  
Who by thy wisdom makest a prince thy servant,  
What wouldst thou have me do?  

**HELICANUS**  
To bear with patience  
Such griefs as you yourself do lay upon yourself.  

**PERICLES**  
Thou speak'st like a physician, Helicanus,  
That minister'st a potion unto me  
That thou wouldst tremble to receive thyself.  
Attend me, then: I went to Antioch,  
Where as thou know'st, against the face of death,  
I sought the purchase of a glorious beauty.  
From whence an issue I might propagate,  
Are arms to princes, and bring joys to subjects.  
Her face was to mine eye beyond all wonder;  
The rest--hark in thine ear--as black as incest:  
Which by my knowledge found, the sinful father  
Seem'd not to strike, but smooth: but thou  
know'st this,  
'Tis time to fear when tyrants seem to kiss.  
Such fear so grew in me, I hither fled,  
Under the covering of a careful night,  
Who seem'd my good protector; and, being here,  
Bethought me what was past, what might succeed.  
I knew him tyrannous; and tyrants' fears  
Decrease not, but grow faster than the years:  
And should he doubt it, as no doubt he doth,  
That I should open to the listening air  
How many worthy princes' bloods were shed,  
To keep his bed of blackness unlaid ope,  
To lop that doubt, he'll fill this land with arms,  
And make pretence of wrong that I have done him:  
When all, for mine, if I may call offence,  
Must feel war's blow, who spares not innocence:  
Which love to all, of which thyself art one,  
Who now reprovest me for it,--  

**HELICANUS**  
Alas, sir!  

**PERICLES**  
Drew sleep out of mine eyes, blood from my cheeks,  
Musings into my mind, with thousand doubts  
How I might stop this tempest ere it came;  
And finding little comfort to relieve them,  
I thought it princely charity to grieve them.  

**HELICANUS**  
Well, my lord, since you have given me leave to speak.  
Freely will I speak. Antiochus you fear,  
And justly too, I think, you fear the tyrant,  
Who either by public war or private treason  
Will take away your life.  
Therefore, my lord, go travel for a while,  
Till that his rage and anger be forgot,  
Or till the Destinies do cut his thread of life.  
Your rule direct to any; if to me.  
Day serves not light more faithful than I'll be.  

**PERICLES**  
I do not doubt thy faith;  
But should he wrong my liberties in my absence?  

**HELICANUS**  
We'll mingle our bloods together in the earth,  
From whence we had our being and our birth.  

**PERICLES**  
Tyre, I now look from thee then, and to Tarsus  
Intend my travel, where I'll hear from thee;  
And by whose letters I'll dispose myself.  
The care I had and have of subjects' good  
On thee I lay whose wisdom's strength can bear it.  
I'll take thy word for faith, not ask thine oath:  
Who shuns not to break one will sure crack both:  
But in our orbs we'll live so round and safe,  
That time of both this truth shall ne'er convince,  
Thou show'dst a subject's shine, I a true prince.  

_Exeunt_

### SCENE III. Tyre. An ante-chamber in the palace.

_Enter THALIARD_

**THALIARD**  
So, this is Tyre, and this the court. Here must I  
kill King Pericles; and if I do it not, I am sure to  
be hanged at home: 'tis dangerous. Well, I perceive  
he was a wise fellow, and had good discretion, that,  
being bid to ask what he would of the king, desired  
he might know none of his secrets: now do I see he  
had some reason for't; for if a king bid a man be a  
villain, he's bound by the indenture of his oath to  
be one! Hush! here come the lords of Tyre.  

_Enter HELICANUS and ESCANES, with other Lords of Tyre_

**HELICANUS**  
You shall not need, my fellow peers of Tyre,  
Further to question me of your king's departure:  
His seal'd commission, left in trust with me,  
Doth speak sufficiently he's gone to travel.  

**THALIARD**  
_[Aside]_  
How! the king gone!  

**HELICANUS**  
If further yet you will be satisfied,  
Why, as it were unlicensed of your loves,  
He would depart, I'll give some light unto you.  
Being at Antioch--  

**THALIARD**  
_[Aside]_  
What from Antioch?  

**HELICANUS**  
Royal Antiochus--on what cause I know not--  
Took some displeasure at him; at least he judged so:  
And doubting lest that he had err'd or sinn'd,  
To show his sorrow, he'ld correct himself;  
So puts himself unto the shipman's toil,  
With whom each minute threatens life or death.  

**THALIARD**  
_[Aside]_  
Well, I perceive  
I shall not be hang'd now, although I would;  
But since he's gone, the king's seas must please:  
He 'scaped the land, to perish at the sea.  
I'll present myself. Peace to the lords of Tyre!  

**HELICANUS**  
Lord Thaliard from Antiochus is welcome.  

**THALIARD**  
From him I come  
With message unto princely Pericles;  
But since my landing I have understood  
Your lord has betook himself to unknown travels,  
My message must return from whence it came.  

**HELICANUS**  
We have no reason to desire it,  
Commended to our master, not to us:  
Yet, ere you shall depart, this we desire,  
As friends to Antioch, we may feast in Tyre.  

_Exeunt_

### SCENE IV. Tarsus. A room in the Governor's house.

_Enter CLEON, the governor of Tarsus, with DIONYZA, and others_

**CLEON**  
My Dionyza, shall we rest us here,  
And by relating tales of others' griefs,  
See if 'twill teach us to forget our own?  

**DIONYZA**  
That were to blow at fire in hope to quench it;  
For who digs hills because they do aspire  
Throws down one mountain to cast up a higher.  
O my distressed lord, even such our griefs are;  
Here they're but felt, and seen with mischief's eyes,  
But like to groves, being topp'd, they higher rise.  

**CLEON**  
O Dionyza,  
Who wanteth food, and will not say he wants it,  
Or can conceal his hunger till he famish?  
Our tongues and sorrows do sound deep  
Our woes into the air; our eyes do weep,  
Till tongues fetch breath that may proclaim them louder;  
That, if heaven slumber while their creatures want,  
They may awake their helps to comfort them.  
I'll then discourse our woes, felt several years,  
And wanting breath to speak help me with tears.  

**DIONYZA**  
I'll do my best, sir.  

**CLEON**  
This Tarsus, o'er which I have the government,  
A city on whom plenty held full hand,  
For riches strew'd herself even in the streets;  
Whose towers bore heads so high they kiss'd the clouds,  
And strangers ne'er beheld but wondered at;  
Whose men and dames so jetted and adorn'd,  
Like one another's glass to trim them by:  
Their tables were stored full, to glad the sight,  
And not so much to feed on as delight;  
All poverty was scorn'd, and pride so great,  
The name of help grew odious to repeat.  

**DIONYZA**  
O, 'tis too true.  

**CLEON**  
But see what heaven can do! By this our change,  
These mouths, who but of late, earth, sea, and air,  
Were all too little to content and please,  
Although they gave their creatures in abundance,  
As houses are defiled for want of use,  
They are now starved for want of exercise:  
Those palates who, not yet two summers younger,  
Must have inventions to delight the taste,  
Would now be glad of bread, and beg for it:  
Those mothers who, to nousle up their babes,  
Thought nought too curious, are ready now  
To eat those little darlings whom they loved.  
So sharp are hunger's teeth, that man and wife  
Draw lots who first shall die to lengthen life:  
Here stands a lord, and there a lady weeping;  
Here many sink, yet those which see them fall  
Have scarce strength left to give them burial.  
Is not this true?  

**DIONYZA**  
Our cheeks and hollow eyes do witness it.  

**CLEON**  
O, let those cities that of plenty's cup  
And her prosperities so largely taste,  
With their superfluous riots, hear these tears!  
The misery of Tarsus may be theirs.  

_Enter a Lord_

**Lord**  
Where's the lord governor?  

**CLEON**  
Here.  
Speak out thy sorrows which thou bring'st in haste,  
For comfort is too far for us to expect.  

**Lord**  
We have descried, upon our neighbouring shore,  
A portly sail of ships make hitherward.  

**CLEON**  
I thought as much.  
One sorrow never comes but brings an heir,  
That may succeed as his inheritor;  
And so in ours: some neighbouring nation,  
Taking advantage of our misery,  
Hath stuff'd these hollow vessels with their power,  
To beat us down, the which are down already;  
And make a conquest of unhappy me,  
Whereas no glory's got to overcome.  

**Lord**  
That's the least fear; for, by the semblance  
Of their white flags display'd, they bring us peace,  
And come to us as favourers, not as foes.  

**CLEON**  
Thou speak'st like him's untutor'd to repeat:  
Who makes the fairest show means most deceit.  
But bring they what they will and what they can,  
What need we fear?  
The ground's the lowest, and we are half way there.  
Go tell their general we attend him here,  
To know for what he comes, and whence he comes,  
And what he craves.  

**Lord**  
I go, my lord.  

_Exit_

**CLEON**  
Welcome is peace, if he on peace consist;  
If wars, we are unable to resist.  

_Enter PERICLES with Attendants_

**PERICLES**  
Lord governor, for so we hear you are,  
Let not our ships and number of our men  
Be like a beacon fired to amaze your eyes.  
We have heard your miseries as far as Tyre,  
And seen the desolation of your streets:  
Nor come we to add sorrow to your tears,  
But to relieve them of their heavy load;  
And these our ships, you happily may think  
Are like the Trojan horse was stuff'd within  
With bloody veins, expecting overthrow,  
Are stored with corn to make your needy bread,  
And give them life whom hunger starved half dead.  

**All**  
The gods of Greece protect you!  
And we'll pray for you.  

**PERICLES**  
Arise, I pray you, rise:  
We do not look for reverence, but to love,  
And harbourage for ourself, our ships, and men.  

**CLEON**  
The which when any shall not gratify,  
Or pay you with unthankfulness in thought,  
Be it our wives, our children, or ourselves,  
The curse of heaven and men succeed their evils!  
Till when,--the which I hope shall ne'er be seen,--  
Your grace is welcome to our town and us.  

**PERICLES**  
Which welcome we'll accept; feast here awhile,  
Until our stars that frown lend us a smile.  

_Exeunt_

# ACT II

_Enter GOWER_

### PROLOGUE

**GOWER**  
Here have you seen a mighty king  
His child, I wis, to incest bring;  
A better prince and benign lord,  
That will prove awful both in deed and word.  
Be quiet then as men should be,  
Till he hath pass'd necessity.  
I'll show you those in troubles reign,  
Losing a mite, a mountain gain.  
The good in conversation,  
To whom I give my benison,  
Is still at Tarsus, where each man  
Thinks all is writ he speken can;  
And, to remember what he does,  
Build his statue to make him glorious:  
But tidings to the contrary  
Are brought your eyes; what need speak I?  
DUMB SHOW.  

_Enter at one door PERICLES talking with CLEON; all the train with them.
Enter at another door a Gentleman, with a letter to PERICLES; PERICLES shows
the letter to CLEON; gives the Messenger a reward, and knights him. Exit
PERICLES at one door, and CLEON at another_

Good Helicane, that stay'd at home,  
Not to eat honey like a drone  
From others' labours; for though he strive  
To killen bad, keep good alive;  
And to fulfil his prince' desire,  
Sends word of all that haps in Tyre:  
How Thaliard came full bent with sin  
And had intent to murder him;  
And that in Tarsus was not best  
Longer for him to make his rest.  
He, doing so, put forth to seas,  
Where when men been, there's seldom ease;  
For now the wind begins to blow;  
Thunder above and deeps below  
Make such unquiet, that the ship  
Should house him safe is wreck'd and split;  
And he, good prince, having all lost,  
By waves from coast to coast is tost:  
All perishen of man, of pelf,  
Ne aught escapen but himself;  
Till fortune, tired with doing bad,  
Threw him ashore, to give him glad:  
And here he comes. What shall be next,  
Pardon old Gower,--this longs the text.  

_Exit_

### SCENE I. Pentapolis. An open place by the sea-side.

_Enter PERICLES, wet_

**PERICLES**  
Yet cease your ire, you angry stars of heaven!  
Wind, rain, and thunder, remember, earthly man  
Is but a substance that must yield to you;  
And I, as fits my nature, do obey you:  
Alas, the sea hath cast me on the rocks,  
Wash'd me from shore to shore, and left me breath  
Nothing to think on but ensuing death:  
Let it suffice the greatness of your powers  
To have bereft a prince of all his fortunes;  
And having thrown him from your watery grave,  
Here to have death in peace is all he'll crave.  

_Enter three FISHERMEN_

**First Fisherman**  
What, ho, Pilch!  

**Second Fisherman**  
Ha, come and bring away the nets!  

**First Fisherman**  
What, Patch-breech, I say!  

**Third Fisherman**  
What say you, master?  

**First Fisherman**  
Look how thou stirrest now! come away, or I'll  
fetch thee with a wanion.  

**Third Fisherman**  
Faith, master, I am thinking of the poor men that  
were cast away before us even now.  

**First Fisherman**  
Alas, poor souls, it grieved my heart to hear what  
pitiful cries they made to us to help them, when,  
well-a-day, we could scarce help ourselves.  

**Third Fisherman**  
Nay, master, said not I as much when I saw the  
porpus how he bounced and tumbled? they say  
they're half fish, half flesh: a plague on them,  
they ne'er come but I look to be washed. Master, I  
marvel how the fishes live in the sea.  

**First Fisherman**  
Why, as men do a-land; the great ones eat up the  
little ones: I can compare our rich misers to  
nothing so fitly as to a whale; a' plays and  
tumbles, driving the poor fry before him, and at  
last devours them all at a mouthful: such whales  
have I heard on o' the land, who never leave gaping  
till they've swallowed the whole parish, church,  
steeple, bells, and all.  

**PERICLES**  
_[Aside]_  
A pretty moral.  

**Third Fisherman**  
But, master, if I had been the sexton, I would have  
been that day in the belfry.  

**Second Fisherman**  
Why, man?  

**Third Fisherman**  
Because he should have swallowed me too: and when I  
had been in his belly, I would have kept such a  
jangling of the bells, that he should never have  
left, till he cast bells, steeple, church, and  
parish up again. But if the good King Simonides  
were of my mind,--  

**PERICLES**  
_[Aside]_  
Simonides!  

**Third Fisherman**  
We would purge the land of these drones, that rob  
the bee of her honey.  

**PERICLES**  
_[Aside]_  
How from the finny subject of the sea  
These fishers tell the infirmities of men;  
And from their watery empire recollect  
All that may men approve or men detect!  
Peace be at your labour, honest fishermen.  

**Second Fisherman**  
Honest! good fellow, what's that? If it be a day  
fits you, search out of the calendar, and nobody  
look after it.  

**PERICLES**  
May see the sea hath cast upon your coast.  

**Second Fisherman**  
What a drunken knave was the sea to cast thee in our  
way!  

**PERICLES**  
A man whom both the waters and the wind,  
In that vast tennis-court, have made the ball  
For them to play upon, entreats you pity him:  
He asks of you, that never used to beg.  

**First Fisherman**  
No, friend, cannot you beg? Here's them in our  
country Greece gets more with begging than we can do  
with working.  

**Second Fisherman**  
Canst thou catch any fishes, then?  

**PERICLES**  
I never practised it.  

**Second Fisherman**  
Nay, then thou wilt starve, sure; for here's nothing  
to be got now-a-days, unless thou canst fish for't.  

**PERICLES**  
What I have been I have forgot to know;  
But what I am, want teaches me to think on:  
A man throng'd up with cold: my veins are chill,  
And have no more of life than may suffice  
To give my tongue that heat to ask your help;  
Which if you shall refuse, when I am dead,  
For that I am a man, pray see me buried.  

**First Fisherman**  
Die quoth-a? Now gods forbid! I have a gown here;  
come, put it on; keep thee warm. Now, afore me, a  
handsome fellow! Come, thou shalt go home, and  
we'll have flesh for holidays, fish for  
fasting-days, and moreo'er puddings and flap-jacks,  
and thou shalt be welcome.  

**PERICLES**  
I thank you, sir.  

**Second Fisherman**  
Hark you, my friend; you said you could not beg.  

**PERICLES**  
I did but crave.  

**Second Fisherman**  
But crave! Then I'll turn craver too, and so I  
shall 'scape whipping.  

**PERICLES**  
Why, are all your beggars whipped, then?  

**Second Fisherman**  
O, not all, my friend, not all; for if all your  
beggars were whipped, I would wish no better office  
than to be beadle. But, master, I'll go draw up the  
net.  

_Exit with Third Fisherman_

**PERICLES**  
_[Aside]_  
How well this honest mirth becomes their labour!  

**First Fisherman**  
Hark you, sir, do you know where ye are?  

**PERICLES**  
Not well.  

**First Fisherman**  
Why, I'll tell you: this is called Pentapolis, and  
our king the good Simonides.  

**PERICLES**  
The good King Simonides, do you call him.  

**First Fisherman**  
Ay, sir; and he deserves so to be called for his  
peaceable reign and good government.  

**PERICLES**  
He is a happy king, since he gains from his subjects  
the name of good by his government. How far is his  
court distant from this shore?  

**First Fisherman**  
Marry, sir, half a day's journey: and I'll tell  
you, he hath a fair daughter, and to-morrow is her  
birth-day; and there are princes and knights come  
from all parts of the world to just and tourney for her love.  

**PERICLES**  
Were my fortunes equal to my desires, I could wish  
to make one there.  

**First Fisherman**  
O, sir, things must be as they may; and what a man  
cannot get, he may lawfully deal for--his wife's soul.  

_Re-enter Second and Third Fishermen, drawing up a net_

**Second Fisherman**  
Help, master, help! here's a fish hangs in the net,  
like a poor man's right in the law; 'twill hardly  
come out. Ha! bots on't, 'tis come at last, and  
'tis turned to a rusty armour.  

**PERICLES**  
An armour, friends! I pray you, let me see it.  
Thanks, fortune, yet, that, after all my crosses,  
Thou givest me somewhat to repair myself;  
And though it was mine own, part of my heritage,  
Which my dead father did bequeath to me.  
With this strict charge, even as he left his life,  
'Keep it, my Pericles; it hath been a shield  
Twixt me and death;'\--and pointed to this brace;--  
'For that it saved me, keep it; in like necessity--  
The which the gods protect thee from!--may  
defend thee.'  
It kept where I kept, I so dearly loved it;  
Till the rough seas, that spare not any man,  
Took it in rage, though calm'd have given't again:  
I thank thee for't: my shipwreck now's no ill,  
Since I have here my father's gift in's will.  

**First Fisherman**  
What mean you, sir?  

**PERICLES**  
To beg of you, kind friends, this coat of worth,  
For it was sometime target to a king;  
I know it by this mark. He loved me dearly,  
And for his sake I wish the having of it;  
And that you'ld guide me to your sovereign's court,  
Where with it I may appear a gentleman;  
And if that ever my low fortune's better,  
I'll pay your bounties; till then rest your debtor.  

**First Fisherman**  
Why, wilt thou tourney for the lady?  

**PERICLES**  
I'll show the virtue I have borne in arms.  

**First Fisherman**  
Why, do 'e take it, and the gods give thee good on't!  

**Second Fisherman**  
Ay, but hark you, my friend; 'twas we that made up  
this garment through the rough seams of the waters:  
there are certain condolements, certain vails. I  
hope, sir, if you thrive, you'll remember from  
whence you had it.  

**PERICLES**  
Believe 't, I will.  
By your furtherance I am clothed in steel;  
And, spite of all the rapture of the sea,  
This jewel holds his building on my arm:  
Unto thy value I will mount myself  
Upon a courser, whose delightful steps  
Shall make the gazer joy to see him tread.  
Only, my friend, I yet am unprovided  
Of a pair of bases.  

**Second Fisherman**  
We'll sure provide: thou shalt have my best gown to  
make thee a pair; and I'll bring thee to the court myself.  

**PERICLES**  
Then honour be but a goal to my will,  
This day I'll rise, or else add ill to ill.  

_Exeunt_

### SCENE II. The same. A public way or platform leading to the

lists. A pavilion by the side of it for the  
reception of King, Princess, Lords, & c.  

_Enter SIMONIDES, THAISA, Lords, and Attendants_

**SIMONIDES**  
Are the knights ready to begin the triumph?  

**First Lord**  
They are, my liege;  
And stay your coming to present themselves.  

**SIMONIDES**  
Return them, we are ready; and our daughter,  
In honour of whose birth these triumphs are,  
Sits here, like beauty's child, whom nature gat  
For men to see, and seeing wonder at.  

_Exit a Lord_

**THAISA**  
It pleaseth you, my royal father, to express  
My commendations great, whose merit's less.  

**SIMONIDES**  
It's fit it should be so; for princes are  
A model which heaven makes like to itself:  
As jewels lose their glory if neglected,  
So princes their renowns if not respected.  
'Tis now your honour, daughter, to explain  
The labour of each knight in his device.  

**THAISA**  
Which, to preserve mine honour, I'll perform.  

_Enter a Knight; he passes over, and his Squire presents his shield to the
Princess_

**SIMONIDES**  
Who is the first that doth prefer himself?  

**THAISA**  
A knight of Sparta, my renowned father;  
And the device he bears upon his shield  
Is a black Ethiope reaching at the sun  
The word, 'Lux tua vita mihi.'  

**SIMONIDES**  
He loves you well that holds his life of you.  

_The Second Knight passes over_

Who is the second that presents himself?  

**THAISA**  
A prince of Macedon, my royal father;  
And the device he bears upon his shield  
Is an arm'd knight that's conquer'd by a lady;  
The motto thus, in Spanish, 'Piu por dulzura que por fuerza.'  

_The Third Knight passes over_

**SIMONIDES**  
And what's the third?  

**THAISA**  
The third of Antioch;  
And his device, a wreath of chivalry;  
The word, 'Me pompae provexit apex.'  

_The Fourth Knight passes over_

**SIMONIDES**  
What is the fourth?  

**THAISA**  
A burning torch that's turned upside down;  
The word, 'Quod me alit, me extinguit.'  

**SIMONIDES**  
Which shows that beauty hath his power and will,  
Which can as well inflame as it can kill.  

_The Fifth Knight passes over_

**THAISA**  
The fifth, an hand environed with clouds,  
Holding out gold that's by the touchstone tried;  
The motto thus, 'Sic spectanda fides.'  

_The Sixth Knight, PERICLES, passes over_

**SIMONIDES**  
And what's  
The sixth and last, the which the knight himself  
With such a graceful courtesy deliver'd?  

**THAISA**  
He seems to be a stranger; but his present is  
A wither'd branch, that's only green at top;  
The motto, 'In hac spe vivo.'  

**SIMONIDES**  
A pretty moral;  
From the dejected state wherein he is,  
He hopes by you his fortunes yet may flourish.  

**First Lord**  
He had need mean better than his outward show  
Can any way speak in his just commend;  
For by his rusty outside he appears  
To have practised more the whipstock than the lance.  

**Second Lord**  
He well may be a stranger, for he comes  
To an honour'd triumph strangely furnished.  

**Third Lord**  
And on set purpose let his armour rust  
Until this day, to scour it in the dust.  

**SIMONIDES**  
Opinion's but a fool, that makes us scan  
The outward habit by the inward man.  
But stay, the knights are coming: we will withdraw  
Into the gallery.  

_Exeunt_

_Great shouts within and all cry 'The mean knight!'_

### SCENE III. The same. A hall of state: a banquet prepared.

_Enter SIMONIDES, THAISA, Lords, Attendants, and Knights, from tilting_

**SIMONIDES**  
Knights,  
To say you're welcome were superfluous.  
To place upon the volume of your deeds,  
As in a title-page, your worth in arms,  
Were more than you expect, or more than's fit,  
Since every worth in show commends itself.  
Prepare for mirth, for mirth becomes a feast:  
You are princes and my guests.  

**THAISA**  
But you, my knight and guest;  
To whom this wreath of victory I give,  
And crown you king of this day's happiness.  

**PERICLES**  
'Tis more by fortune, lady, than by merit.  

**SIMONIDES**  
Call it by what you will, the day is yours;  
And here, I hope, is none that envies it.  
In framing an artist, art hath thus decreed,  
To make some good, but others to exceed;  
And you are her labour'd scholar. Come, queen o'  
the feast,--  
For, daughter, so you are,--here take your place:  
Marshal the rest, as they deserve their grace.  

**KNIGHTS**  
We are honour'd much by good Simonides.  

**SIMONIDES**  
Your presence glads our days: honour we love;  
For who hates honour hates the gods above.  

**Marshal**  
Sir, yonder is your place.  

**PERICLES**  
Some other is more fit.  

**First Knight**  
Contend not, sir; for we are gentlemen  
That neither in our hearts nor outward eyes  
Envy the great nor do the low despise.  

**PERICLES**  
You are right courteous knights.  

**SIMONIDES**  
Sit, sir, sit.  

**PERICLES**  
By Jove, I wonder, that is king of thoughts,  
These cates resist me, she but thought upon.  

**THAISA**  
By Juno, that is queen of marriage,  
All viands that I eat do seem unsavoury.  
Wishing him my meat. Sure, he's a gallant gentleman.  

**SIMONIDES**  
He's but a country gentleman;  
Has done no more than other knights have done;  
Has broken a staff or so; so let it pass.  

**THAISA**  
To me he seems like diamond to glass.  

**PERICLES**  
Yon king's to me like to my father's picture,  
Which tells me in that glory once he was;  
Had princes sit, like stars, about his throne,  
And he the sun, for them to reverence;  
None that beheld him, but, like lesser lights,  
Did vail their crowns to his supremacy:  
Where now his son's like a glow-worm in the night,  
The which hath fire in darkness, none in light:  
Whereby I see that Time's the king of men,  
He's both their parent, and he is their grave,  
And gives them what he will, not what they crave.  

**SIMONIDES**  
What, are you merry, knights?  

**Knights**  
Who can be other in this royal presence?  

**SIMONIDES**  
Here, with a cup that's stored unto the brim,--  
As you do love, fill to your mistress' lips,--  
We drink this health to you.  

**KNIGHTS**  
We thank your grace.  

**SIMONIDES**  
Yet pause awhile:  
Yon knight doth sit too melancholy,  
As if the entertainment in our court  
Had not a show might countervail his worth.  
Note it not you, Thaisa?  

**THAISA**  
What is it  
To me, my father?  

**SIMONIDES**  
O, attend, my daughter:  
Princes in this should live like gods above,  
Who freely give to every one that comes  
To honour them:  
And princes not doin g so are like to gnats,  
Which make a sound, but kill'd are wonder'd at.  
Therefore to make his entrance more sweet,  
Here, say we drink this standing-bowl of wine to him.  

**THAISA**  
Alas, my father, it befits not me  
Unto a stranger knight to be so bold:  
He may my proffer take for an offence,  
Since men take women's gifts for impudence.  

**SIMONIDES**  
How!  
Do as I bid you, or you'll move me else.  

**THAISA**  
_[Aside]_  
Now, by the gods, he could not please me better.  

**SIMONIDES**  
And furthermore tell him, we desire to know of him,  
Of whence he is, his name and parentage.  

**THAISA**  
The king my father, sir, has drunk to you.  

**PERICLES**  
I thank him.  

**THAISA**  
Wishing it so much blood unto your life.  

**PERICLES**  
I thank both him and you, and pledge him freely.  

**THAISA**  
And further he desires to know of you,  
Of whence you are, your name and parentage.  

**PERICLES**  
A gentleman of Tyre; my name, Pericles;  
My education been in arts and arms;  
Who, looking for adventures in the world,  
Was by the rough seas reft of ships and men,  
And after shipwreck driven upon this shore.  

**THAISA**  
He thanks your grace; names himself Pericles,  
A gentleman of Tyre,  
Who only by misfortune of the seas  
Bereft of ships and men, cast on this shore.  

**SIMONIDES**  
Now, by the gods, I pity his misfortune,  
And will awake him from his melancholy.  
Come, gentlemen, we sit too long on trifles,  
And waste the time, which looks for other revels.  
Even in your armours, as you are address'd,  
Will very well become a soldier's dance.  
I will not have excuse, with saying this  
Loud music is too harsh for ladies' heads,  
Since they love men in arms as well as beds.  

_The Knights dance_

So, this was well ask'd,'twas so well perform'd.  
Come, sir;  
Here is a lady that wants breathing too:  
And I have heard, you knights of Tyre  
Are excellent in making ladies trip;  
And that their measures are as excellent.  

**PERICLES**  
In those that practise them they are, my lord.  

**SIMONIDES**  
O, that's as much as you would be denied  
Of your fair courtesy.  

_The Knights and Ladies dance_

Unclasp, unclasp:  
Thanks, gentlemen, to all; all have done well.  

_To PERICLES_

But you the best. Pages and lights, to conduct  
These knights unto their several lodgings!  

_To PERICLES_

Yours, sir,  
We have given order to be next our own.  

**PERICLES**  
I am at your grace's pleasure.  

**SIMONIDES**  
Princes, it is too late to talk of love;  
And that's the mark I know you level at:  
Therefore each one betake him to his rest;  
To-morrow all for speeding do their best.  

_Exeunt_

### SCENE IV. Tyre. A room in the Governor's house.

_Enter HELICANUS and ESCANES_

**HELICANUS**  
No, Escanes, know this of me,  
Antiochus from incest lived not free:  
For which, the most high gods not minding longer  
To withhold the vengeance that they had in store,  
Due to this heinous capital offence,  
Even in the height and pride of all his glory,  
When he was seated in a chariot  
Of an inestimable value, and his daughter with him,  
A fire from heaven came and shrivell'd up  
Their bodies, even to loathing; for they so stunk,  
That all those eyes adored them ere their fall  
Scorn now their hand should give them burial.  

**ESCANES**  
'Twas very strange.  

**HELICANUS**  
And yet but justice; for though  
This king were great, his greatness was no guard  
To bar heaven's shaft, but sin had his reward.  

**ESCANES**  
'Tis very true.  

_Enter two or three Lords_

**First Lord**  
See, not a man in private conference  
Or council has respect with him but he.  

**Second Lord**  
It shall no longer grieve without reproof.  

**Third Lord**  
And cursed be he that will not second it.  

**First Lord**  
Follow me, then. Lord Helicane, a word.  

**HELICANUS**  
With me? and welcome: happy day, my lords.  

**First Lord**  
Know that our griefs are risen to the top,  
And now at length they overflow their banks.  

**HELICANUS**  
Your griefs! for what? wrong not your prince you love.  

**First Lord**  
Wrong not yourself, then, noble Helicane;  
But if the prince do live, let us salute him,  
Or know what ground's made happy by his breath.  
If in the world he live, we'll seek him out;  
If in his grave he rest, we'll find him there;  
And be resolved he lives to govern us,  
Or dead, give's cause to mourn his funeral,  
And leave us to our free election.  

**Second Lord**  
Whose death indeed's the strongest in our censure:  
And knowing this kingdom is without a head,--  
Like goodly buildings left without a roof  
Soon fall to ruin,--your noble self,  
That best know how to rule and how to reign,  
We thus submit unto,--our sovereign.  

**All**  
Live, noble Helicane!  

**HELICANUS**  
For honour's cause, forbear your suffrages:  
If that you love Prince Pericles, forbear.  
Take I your wish, I leap into the seas,  
Where's hourly trouble for a minute's ease.  
A twelvemonth longer, let me entreat you to  
Forbear the absence of your king:  
If in which time expired, he not return,  
I shall with aged patience bear your yoke.  
But if I cannot win you to this love,  
Go search like nobles, like noble subjects,  
And in your search spend your adventurous worth;  
Whom if you find, and win unto return,  
You shall like diamonds sit about his crown.  

**First Lord**  
To wisdom he's a fool that will not yield;  
And since Lord Helicane enjoineth us,  
We with our travels will endeavour us.  

**HELICANUS**  
Then you love us, we you, and we'll clasp hands:  
When peers thus knit, a kingdom ever stands.  

_Exeunt_

### SCENE V. Pentapolis. A room in the palace.

_Enter SIMONIDES, reading a letter, at one door: the Knights meet him_

**First Knight**  
Good morrow to the good Simonides.  

**SIMONIDES**  
Knights, from my daughter this I let you know,  
That for this twelvemonth she'll not undertake  
A married life.  
Her reason to herself is only known,  
Which yet from her by no means can I get.  

**Second Knight**  
May we not get access to her, my lord?  

**SIMONIDES**  
'Faith, by no means; she has so strictly tied  
Her to her chamber, that 'tis impossible.  
One twelve moons more she'll wear Diana's livery;  
This by the eye of Cynthia hath she vow'd  
And on her virgin honour will not break it.  

**Third Knight**  
Loath to bid farewell, we take our leaves.  

_Exeunt Knights_

**SIMONIDES**  
So,  
They are well dispatch'd; now to my daughter's letter:  
She tells me here, she'd wed the stranger knight,  
Or never more to view nor day nor light.  
'Tis well, mistress; your choice agrees with mine;  
I like that well: nay, how absolute she's in't,  
Not minding whether I dislike or no!  
Well, I do commend her choice;  
And will no longer have it be delay'd.  
Soft! here he comes: I must dissemble it.  

_Enter PERICLES_

**PERICLES**  
All fortune to the good Simonides!  

**SIMONIDES**  
To you as much, sir! I am beholding to you  
For your sweet music this last night: I do  
Protest my ears were never better fed  
With such delightful pleasing harmony.  

**PERICLES**  
It is your grace's pleasure to commend;  
Not my desert.  

**SIMONIDES**  
Sir, you are music's master.  

**PERICLES**  
The worst of all her scholars, my good lord.  

**SIMONIDES**  
Let me ask you one thing:  
What do you think of my daughter, sir?  

**PERICLES**  
A most virtuous princess.  

**SIMONIDES**  
And she is fair too, is she not?  

**PERICLES**  
As a fair day in summer, wondrous fair.  

**SIMONIDES**  
Sir, my daughter thinks very well of you;  
Ay, so well, that you must be her master,  
And she will be your scholar: therefore look to it.  

**PERICLES**  
I am unworthy for her schoolmaster.  

**SIMONIDES**  
She thinks not so; peruse this writing else.  

**PERICLES**  
_[Aside]_  
What's here?  
A letter, that she loves the knight of Tyre!  
'Tis the king's subtlety to have my life.  
O, seek not to entrap me, gracious lord,  
A stranger and distressed gentleman,  
That never aim'd so high to love your daughter,  
But bent all offices to honour her.  

**SIMONIDES**  
Thou hast bewitch'd my daughter, and thou art  
A villain.  

**PERICLES**  
By the gods, I have not:  
Never did thought of mine levy offence;  
Nor never did my actions yet commence  
A deed might gain her love or your displeasure.  

**SIMONIDES**  
Traitor, thou liest.  

**PERICLES**  
Traitor!  

**SIMONIDES**  
Ay, traitor.  

**PERICLES**  
Even in his throat--unless it be the king--  
That calls me traitor, I return the lie.  

**SIMONIDES**  
_[Aside]_  
Now, by the gods, I do applaud his courage.  

**PERICLES**  
My actions are as noble as my thoughts,  
That never relish'd of a base descent.  
I came unto your court for honour's cause,  
And not to be a rebel to her state;  
And he that otherwise accounts of me,  
This sword shall prove he's honour's enemy.  

**SIMONIDES**  
No?  
Here comes my daughter, she can witness it.  

_Enter THAISA_

**PERICLES**  
Then, as you are as virtuous as fair,  
Resolve your angry father, if my tongue  
Did ere solicit, or my hand subscribe  
To any syllable that made love to you.  

**THAISA**  
Why, sir, say if you had,  
Who takes offence at that would make me glad?  

**SIMONIDES**  
Yea, mistress, are you so peremptory?  

_Aside_

I am glad on't with all my heart.--  
I'll tame you; I'll bring you in subjection.  
Will you, not having my consent,  
Bestow your love and your affections  
Upon a stranger?  

_Aside_

who, for aught I know,  
May be, nor can I think the contrary,  
As great in blood as I myself.--  
Therefore hear you, mistress; either frame  
Your will to mine,--and you, sir, hear you,  
Either be ruled by me, or I will make you--  
Man and wife:  
Nay, come, your hands and lips must seal it too:  
And being join'd, I'll thus your hopes destroy;  
And for a further grief,--God give you joy!--  
What, are you both pleased?  

**THAISA**  
Yes, if you love me, sir.  

**PERICLES**  
Even as my life, or blood that fosters it.  

**SIMONIDES**  
What, are you both agreed?  

**BOTH**  
Yes, if it please your majesty.  

**SIMONIDES**  
It pleaseth me so well, that I will see you wed;  
And then with what haste you can get you to bed.  

_Exeunt_

# ACT III

_Enter GOWER_

### PROLOGUE

**GOWER**  
Now sleep y-slaked hath the rout;  
No din but snores the house about,  
Made louder by the o'er-fed breast  
Of this most pompous marriage-feast.  
The cat, with eyne of burning coal,  
Now crouches fore the mouse's hole;  
And crickets sing at the oven's mouth,  
E'er the blither for their drouth.  
Hymen hath brought the bride to bed.  
Where, by the loss of maidenhead,  
A babe is moulded. Be attent,  
And time that is so briefly spent  
With your fine fancies quaintly eche:  
What's dumb in show I'll plain with speech.  
DUMB SHOW.  

_Enter, PERICLES and SIMONIDES at one door, with Attendants; a Messenger
meets them, kneels, and gives PERICLES a letter: PERICLES shows it SIMONIDES;
the Lords kneel to him. Then enter THAISA with child, with LYCHORIDA a nurse.
The KING shows her the letter; she rejoices: she and PERICLES takes leave of
her father, and depart with LYCHORIDA and their Attendants. Then exeunt
SIMONIDES and the rest_

By many a dern and painful perch  
Of Pericles the careful search,  
By the four opposing coigns  
Which the world together joins,  
Is made with all due diligence  
That horse and sail and high expense  
Can stead the quest. At last from Tyre,  
Fame answering the most strange inquire,  
To the court of King Simonides  
Are letters brought, the tenor these:  
Antiochus and his daughter dead;  
The men of Tyrus on the head  
Of Helicanus would set on  
The crown of Tyre, but he will none:  
The mutiny he there hastes t' oppress;  
Says to 'em, if King Pericles  
Come not home in twice six moons,  
He, obedient to their dooms,  
Will take the crown. The sum of this,  
Brought hither to Pentapolis,  
Y-ravished the regions round,  
And every one with claps can sound,  
'Our heir-apparent is a king!  
Who dream'd, who thought of such a thing?'  
Brief, he must hence depart to Tyre:  
His queen with child makes her desire--  
Which who shall cross?--along to go:  
Omit we all their dole and woe:  
Lychorida, her nurse, she takes,  
And so to sea. Their vessel shakes  
On Neptune's billow; half the flood  
Hath their keel cut: but fortune's mood  
Varies again; the grisly north  
Disgorges such a tempest forth,  
That, as a duck for life that dives,  
So up and down the poor ship drives:  
The lady shrieks, and well-a-near  
Does fall in travail with her fear:  
And what ensues in this fell storm  
Shall for itself itself perform.  
I nill relate, action may  
Conveniently the rest convey;  
Which might not what by me is told.  
In your imagination hold  
This stage the ship, upon whose deck  
The sea-tost Pericles appears to speak.  

_Exit_

SCENE I:  

_Enter PERICLES, on shipboard_

**PERICLES**  
Thou god of this great vast, rebuke these surges,  
Which wash both heaven and hell; and thou, that hast  
Upon the winds command, bind them in brass,  
Having call'd them from the deep! O, still  
Thy deafening, dreadful thunders; gently quench  
Thy nimble, sulphurous flashes! O, how, Lychorida,  
How does my queen? Thou stormest venomously;  
Wilt thou spit all thyself? The seaman's whistle  
Is as a whisper in the ears of death,  
Unheard. Lychorida!--Lucina, O  
Divinest patroness, and midwife gentle  
To those that cry by night, convey thy deity  
Aboard our dancing boat; make swift the pangs  
Of my queen's travails!  

_Enter LYCHORIDA, with an Infant_

Now, Lychorida!  

**LYCHORIDA**  
Here is a thing too young for such a place,  
Who, if it had conceit, would die, as I  
Am like to do: take in your arms this piece  
Of your dead queen.  

**PERICLES**  
How, how, Lychorida!  

**LYCHORIDA**  
Patience, good sir; do not assist the storm.  
Here's all that is left living of your queen,  
A little daughter: for the sake of it,  
Be manly, and take comfort.  

**PERICLES**  
O you gods!  
Why do you make us love your goodly gifts,  
And snatch them straight away? We here below  
Recall not what we give, and therein may  
Use honour with you.  

**LYCHORIDA**  
Patience, good sir,  
Even for this charge.  

**PERICLES**  
Now, mild may be thy life!  
For a more blustrous birth had never babe:  
Quiet and gentle thy conditions! for  
Thou art the rudeliest welcome to this world  
That ever was prince's child. Happy what follows!  
Thou hast as chiding a nativity  
As fire, air, water, earth, and heaven can make,  
To herald thee from the womb: even at the first  
Thy loss is more than can thy portage quit,  
With all thou canst find here. Now, the good gods  
Throw their best eyes upon't!  

_Enter two Sailors_

**First Sailor**  
What courage, sir? God save you!  

**PERICLES**  
Courage enough: I do not fear the flaw;  
It hath done to me the worst. Yet, for the love  
Of this poor infant, this fresh-new sea-farer,  
I would it would be quiet.  

**First Sailor**  
Slack the bolins there! Thou wilt not, wilt thou?  
Blow, and split thyself.  

**Second Sailor**  
But sea-room, an the brine and cloudy billow kiss  
the moon, I care not.  

**First Sailor**  
Sir, your queen must overboard: the sea works high,  
the wind is loud, and will not lie till the ship be  
cleared of the dead.  

**PERICLES**  
That's your superstition.  

**First Sailor**  
Pardon us, sir; with us at sea it hath been still  
observed: and we are strong in custom. Therefore  
briefly yield her; for she must overboard straight.  

**PERICLES**  
As you think meet. Most wretched queen!  

**LYCHORIDA**  
Here she lies, sir.  

**PERICLES**  
A terrible childbed hast thou had, my dear;  
No light, no fire: the unfriendly elements  
Forgot thee utterly: nor have I time  
To give thee hallow'd to thy grave, but straight  
Must cast thee, scarcely coffin'd, in the ooze;  
Where, for a monument upon thy bones,  
And e'er-remaining lamps, the belching whale  
And humming water must o'erwhelm thy corpse,  
Lying with simple shells. O Lychorida,  
Bid Nestor bring me spices, ink and paper,  
My casket and my jewels; and bid Nicander  
Bring me the satin coffer: lay the babe  
Upon the pillow: hie thee, whiles I say  
A priestly farewell to her: suddenly, woman.  

_Exit LYCHORIDA_

**Second Sailor**  
Sir, we have a chest beneath the hatches, caulked  
and bitumed ready.  

**PERICLES**  
I thank thee. Mariner, say what coast is this?  

**Second Sailor**  
We are near Tarsus.  

**PERICLES**  
Thither, gentle mariner.  
Alter thy course for Tyre. When canst thou reach it?  

**Second Sailor**  
By break of day, if the wind cease.  

**PERICLES**  
O, make for Tarsus!  
There will I visit Cleon, for the babe  
Cannot hold out to Tyrus: there I'll leave it  
At careful nursing. Go thy ways, good mariner:  
I'll bring the body presently.  

_Exeunt_

### SCENE II. Ephesus. A room in CERIMON's house.

_Enter CERIMON, with a Servant, and some Persons who have been shipwrecked_

**CERIMON**  
Philemon, ho!  

_Enter PHILEMON_

**PHILEMON**  
Doth my lord call?  

**CERIMON**  
Get fire and meat for these poor men:  
'T has been a turbulent and stormy night.  

**Servant**  
I have been in many; but such a night as this,  
Till now, I ne'er endured.  

**CERIMON**  
Your master will be dead ere you return;  
There's nothing can be minister'd to nature  
That can recover him.  

_To PHILEMON_

Give this to the 'pothecary,  
And tell me how it works.  

_Exeunt all but CERIMON_

_Enter two Gentlemen_

**First Gentleman**  
Good morrow.  

**Second Gentleman**  
Good morrow to your lordship.  

**CERIMON**  
Gentlemen,  
Why do you stir so early?  

**First Gentleman**  
Sir,  
Our lodgings, standing bleak upon the sea,  
Shook as the earth did quake;  
The very principals did seem to rend,  
And all-to topple: pure surprise and fear  
Made me to quit the house.  

**Second Gentleman**  
That is the cause we trouble you so early;  
'Tis not our husbandry.  

**CERIMON**  
O, you say well.  

**First Gentleman**  
But I much marvel that your lordship, having  
Rich tire about you, should at these early hours  
Shake off the golden slumber of repose.  
'Tis most strange,  
Nature should be so conversant with pain,  
Being thereto not compell'd.  

**CERIMON**  
I hold it ever,  
Virtue and cunning were endowments greater  
Than nobleness and riches: careless heirs  
May the two latter darken and expend;  
But immortality attends the former.  
Making a man a god. 'Tis known, I ever  
Have studied physic, through which secret art,  
By turning o'er authorities, I have,  
Together with my practise, made familiar  
To me and to my aid the blest infusions  
That dwell in vegetives, in metals, stones;  
And I can speak of the disturbances  
That nature works, and of her cures; which doth give me  
A more content in course of true delight  
Than to be thirsty after tottering honour,  
Or tie my treasure up in silken bags,  
To please the fool and death.  

**Second Gentleman**  
Your honour has through Ephesus pour'd forth  
Your charity, and hundreds call themselves  
Your creatures, who by you have been restored:  
And not your knowledge, your personal pain, but even  
Your purse, still open, hath built Lord Cerimon  
Such strong renown as time shall ne'er decay.  

_Enter two or three Servants with a chest_

**First Servant**  
So; lift there.  

**CERIMON**  
What is that?  

**First Servant**  
Sir, even now  
Did the sea toss upon our shore this chest:  
'Tis of some wreck.  

**CERIMON**  
Set 't down, let's look upon't.  

**Second Gentleman**  
'Tis like a coffin, sir.  

**CERIMON**  
Whate'er it be,  
'Tis wondrous heavy. Wrench it open straight:  
If the sea's stomach be o'ercharged with gold,  
'Tis a good constraint of fortune it belches upon us.  

**Second Gentleman**  
'Tis so, my lord.  

**CERIMON**  
How close 'tis caulk'd and bitumed!  
Did the sea cast it up?  

**First Servant**  
I never saw so huge a billow, sir,  
As toss'd it upon shore.  

**CERIMON**  
Wrench it open;  
Soft! it smells most sweetly in my sense.  

**Second Gentleman**  
A delicate odour.  

**CERIMON**  
As ever hit my nostril. So, up with it.  
O you most potent gods! what's here? a corse!  

**First Gentleman**  
Most strange!  

**CERIMON**  
Shrouded in cloth of state; balm'd and entreasured  
With full bags of spices! A passport too!  
Apollo, perfect me in the characters!  

_Reads from a scroll_

'Here I give to understand,  
If e'er this coffin drive a-land,  
I, King Pericles, have lost  
This queen, worth all our mundane cost.  
Who finds her, give her burying;  
She was the daughter of a king:  
Besides this treasure for a fee,  
The gods requite his charity!'  
If thou livest, Pericles, thou hast a heart  
That even cracks for woe! This chanced tonight.  

**Second Gentleman**  
Most likely, sir.  

**CERIMON**  
Nay, certainly to-night;  
For look how fresh she looks! They were too rough  
That threw her in the sea. Make a fire within:  
Fetch hither all my boxes in my closet.  

_Exit a Servant_

Death may usurp on nature many hours,  
And yet the fire of life kindle again  
The o'erpress'd spirits. I heard of an Egyptian  
That had nine hours lien dead,  
Who was by good appliance recovered.  

_Re-enter a Servant, with boxes, napkins, and fire_

Well said, well said; the fire and cloths.  
The rough and woeful music that we have,  
Cause it to sound, beseech you.  
The viol once more: how thou stirr'st, thou block!  
The music there!--I pray you, give her air.  
Gentlemen.  
This queen will live: nature awakes; a warmth  
Breathes out of her: she hath not been entranced  
Above five hours: see how she gins to blow  
Into life's flower again!  

**First Gentleman**  
The heavens,  
Through you, increase our wonder and set up  
Your fame forever.  

**CERIMON**  
She is alive; behold,  
Her eyelids, cases to those heavenly jewels  
Which Pericles hath lost,  
Begin to part their fringes of bright gold;  
The diamonds of a most praised water  
Do appear, to make the world twice rich. Live,  
And make us weep to hear your fate, fair creature,  
Rare as you seem to be.  

_She moves_

**THAISA**  
O dear Diana,  
Where am I? Where's my lord? What world is this?  

**Second Gentleman**  
Is not this strange?  

**First Gentleman**  
Most rare.  

**CERIMON**  
Hush, my gentle neighbours!  
Lend me your hands; to the next chamber bear her.  
Get linen: now this matter must be look'd to,  
For her relapse is mortal. Come, come;  
And AEsculapius guide us!  

_Exeunt, carrying her away_

### SCENE III. Tarsus. A room in CLEON's house.

_Enter PERICLES, CLEON, DIONYZA, and LYCHORIDA with MARINA in her arms_

**PERICLES**  
Most honour'd Cleon, I must needs be gone;  
My twelve months are expired, and Tyrus stands  
In a litigious peace. You, and your lady,  
Take from my heart all thankfulness! The gods  
Make up the rest upon you!  

**CLEON**  
Your shafts of fortune, though they hurt you mortally,  
Yet glance full wanderingly on us.  

**DIONYZA**  
O your sweet queen!  
That the strict fates had pleased you had brought her hither,  
To have bless'd mine eyes with her!  

**PERICLES**  
We cannot but obey  
The powers above us. Could I rage and roar  
As doth the sea she lies in, yet the end  
Must be as 'tis. My gentle babe Marina, whom,  
For she was born at sea, I have named so, here  
I charge your charity withal, leaving her  
The infant of your care; beseeching you  
To give her princely training, that she may be  
Manner'd as she is born.  

**CLEON**  
Fear not, my lord, but think  
Your grace, that fed my country with your corn,  
For which the people's prayers still fall upon you,  
Must in your child be thought on. If neglection  
Should therein make me vile, the common body,  
By you relieved, would force me to my duty:  
But if to that my nature need a spur,  
The gods revenge it upon me and mine,  
To the end of generation!  

**PERICLES**  
I believe you;  
Your honour and your goodness teach me to't,  
Without your vows. Till she be married, madam,  
By bright Diana, whom we honour, all  
Unscissor'd shall this hair of mine remain,  
Though I show ill in't. So I take my leave.  
Good madam, make me blessed in your care  
In bringing up my child.  

**DIONYZA**  
I have one myself,  
Who shall not be more dear to my respect  
Than yours, my lord.  

**PERICLES**  
Madam, my thanks and prayers.  

**CLEON**  
We'll bring your grace e'en to the edge o' the shore,  
Then give you up to the mask'd Neptune and  
The gentlest winds of heaven.  

**PERICLES**  
I will embrace  
Your offer. Come, dearest madam. O, no tears,  
Lychorida, no tears:  
Look to your little mistress, on whose grace  
You may depend hereafter. Come, my lord.  

_Exeunt_

### SCENE IV. Ephesus. A room in CERIMON's house.

_Enter CERIMON and THAISA_

**CERIMON**  
Madam, this letter, and some certain jewels,  
Lay with you in your coffer: which are now  
At your command. Know you the character?  

**THAISA**  
It is my lord's.  
That I was shipp'd at sea, I well remember,  
Even on my eaning time; but whether there  
Deliver'd, by the holy gods,  
I cannot rightly say. But since King Pericles,  
My wedded lord, I ne'er shall see again,  
A vestal livery will I take me to,  
And never more have joy.  

**CERIMON**  
Madam, if this you purpose as ye speak,  
Diana's temple is not distant far,  
Where you may abide till your date expire.  
Moreover, if you please, a niece of mine  
Shall there attend you.  

**THAISA**  
My recompense is thanks, that's all;  
Yet my good will is great, though the gift small.  

_Exeunt_

# ACT IV

### PROLOGUE

_Enter GOWER_

**GOWER**  
Imagine Pericles arrived at Tyre,  
Welcomed and settled to his own desire.  
His woeful queen we leave at Ephesus,  
Unto Diana there a votaress.  
Now to Marina bend your mind,  
Whom our fast-growing scene must find  
At Tarsus, and by Cleon train'd  
In music, letters; who hath gain'd  
Of education all the grace,  
Which makes her both the heart and place  
Of general wonder. But, alack,  
That monster envy, oft the wrack  
Of earned praise, Marina's life  
Seeks to take off by treason's knife.  
And in this kind hath our Cleon  
One daughter, and a wench full grown,  
Even ripe for marriage-rite; this maid  
Hight Philoten: and it is said  
For certain in our story, she  
Would ever with Marina be:  
Be't when she weaved the sleided silk  
With fingers long, small, white as milk;  
Or when she would with sharp needle wound  
The cambric, which she made more sound  
By hurting it; or when to the lute  
She sung, and made the night-bird mute,  
That still records with moan; or when  
She would with rich and constant pen  
Vail to her mistress Dian; still  
This Philoten contends in skill  
With absolute Marina: so  
With the dove of Paphos might the crow  
Vie feathers white. Marina gets  
All praises, which are paid as debts,  
And not as given. This so darks  
In Philoten all graceful marks,  
That Cleon's wife, with envy rare,  
A present murderer does prepare  
For good Marina, that her daughter  
Might stand peerless by this slaughter.  
The sooner her vile thoughts to stead,  
Lychorida, our nurse, is dead:  
And cursed Dionyza hath  
The pregnant instrument of wrath  
Prest for this blow. The unborn event  
I do commend to your content:  
Only I carry winged time  
Post on the lame feet of my rhyme;  
Which never could I so convey,  
Unless your thoughts went on my way.  
Dionyza does appear,  
With Leonine, a murderer.  

_Exit_

### SCENE I. Tarsus. An open place near the sea-shore.

_Enter DIONYZA and LEONINE_

**DIONYZA**  
Thy oath remember; thou hast sworn to do't:  
'Tis but a blow, which never shall be known.  
Thou canst not do a thing in the world so soon,  
To yield thee so much profit. Let not conscience,  
Which is but cold, inflaming love i' thy bosom,  
Inflame too nicely; nor let pity, which  
Even women have cast off, melt thee, but be  
A soldier to thy purpose.  

**LEONINE**  
I will do't; but yet she is a goodly creature.  

**DIONYZA**  
The fitter, then, the gods should have her. Here  
she comes weeping for her only mistress' death.  
Thou art resolved?  

**LEONINE**  
I am resolved.  

_Enter MARINA, with a basket of flowers_

**MARINA**  
No, I will rob Tellus of her weed,  
To strew thy green with flowers: the yellows, blues,  
The purple violets, and marigolds,  
Shall as a carpet hang upon thy grave,  
While summer-days do last. Ay me! poor maid,  
Born in a tempest, when my mother died,  
This world to me is like a lasting storm,  
Whirring me from my friends.  

**DIONYZA**  
How now, Marina! why do you keep alone?  
How chance my daughter is not with you? Do not  
Consume your blood with sorrowing: you have  
A nurse of me. Lord, how your favour's changed  
With this unprofitable woe!  
Come, give me your flowers, ere the sea mar it.  
Walk with Leonine; the air is quick there,  
And it pierces and sharpens the stomach. Come,  
Leonine, take her by the arm, walk with her.  

**MARINA**  
No, I pray you;  
I'll not bereave you of your servant.  

**DIONYZA**  
Come, come;  
I love the king your father, and yourself,  
With more than foreign heart. We every day  
Expect him here: when he shall come and find  
Our paragon to all reports thus blasted,  
He will repent the breadth of his great voyage;  
Blame both my lord and me, that we have taken  
No care to your best courses. Go, I pray you,  
Walk, and be cheerful once again; reserve  
That excellent complexion, which did steal  
The eyes of young and old. Care not for me  
I can go home alone.  

**MARINA**  
Well, I will go;  
But yet I have no desire to it.  

**DIONYZA**  
Come, come, I know 'tis good for you.  
Walk half an hour, Leonine, at the least:  
Remember what I have said.  

**LEONINE**  
I warrant you, madam.  

**DIONYZA**  
I'll leave you, my sweet lady, for a while:  
Pray, walk softly, do not heat your blood:  
What! I must have a care of you.  

**MARINA**  
My thanks, sweet madam.  

_Exit DIONYZA_

Is this wind westerly that blows?  

**LEONINE**  
South-west.  

**MARINA**  
When I was born, the wind was north.  

**LEONINE**  
Was't so?  

**MARINA**  
My father, as nurse said, did never fear,  
But cried 'Good seaman!' to the sailors, galling  
His kingly hands, haling ropes;  
And, clasping to the mast, endured a sea  
That almost burst the deck.  

**LEONINE**  
When was this?  

**MARINA**  
When I was born:  
Never was waves nor wind more violent;  
And from the ladder-tackle washes off  
A canvas-climber. 'Ha!' says one, 'wilt out?'  
And with a dropping industry they skip  
From stem to stern: the boatswain whistles, and  
The master calls, and trebles their confusion.  

**LEONINE**  
Come, say your prayers.  

**MARINA**  
What mean you?  

**LEONINE**  
If you require a little space for prayer,  
I grant it: pray; but be not tedious,  
For the gods are quick of ear, and I am sworn  
To do my work with haste.  

**MARINA**  
Why will you kill me?  

**LEONINE**  
To satisfy my lady.  

**MARINA**  
Why would she have me kill'd?  
Now, as I can remember, by my troth,  
I never did her hurt in all my life:  
I never spake bad word, nor did ill turn  
To any living creature: believe me, la,  
I never kill'd a mouse, nor hurt a fly:  
I trod upon a worm against my will,  
But I wept for it. How have I offended,  
Wherein my death might yield her any profit,  
Or my life imply her any danger?  

**LEONINE**  
My commission  
Is not to reason of the deed, but do it.  

**MARINA**  
You will not do't for all the world, I hope.  
You are well favour'd, and your looks foreshow  
You have a gentle heart. I saw you lately,  
When you caught hurt in parting two that fought:  
Good sooth, it show'd well in you: do so now:  
Your lady seeks my life; come you between,  
And save poor me, the weaker.  

**LEONINE**  
I am sworn,  
And will dispatch.  

_He seizes her_

_Enter Pirates_

**First Pirate**  
Hold, villain!  

_LEONINE runs away_

**Second Pirate**  
A prize! a prize!  

**Third Pirate**  
Half-part, mates, half-part.  
Come, let's have her aboard suddenly.  

_Exeunt Pirates with MARINA_

_Re-enter LEONINE_

**LEONINE**  
These roguing thieves serve the great pirate Valdes;  
And they have seized Marina. Let her go:  
There's no hope she will return. I'll swear  
she's dead,  
And thrown into the sea. But I'll see further:  
Perhaps they will but please themselves upon her,  
Not carry her aboard. If she remain,  
Whom they have ravish'd must by me be slain.  

_Exit_

### SCENE II. Mytilene. A room in a brothel.

_Enter Pandar, Bawd, and BOULT_

**Pandar**  
Boult!  

**BOULT**  
Sir?  

**Pandar**  
Search the market narrowly; Mytilene is full of  
gallants. We lost too much money this mart by being  
too wenchless.  

**Bawd**  
We were never so much out of creatures. We have but  
poor three, and they can do no more than they can  
do; and they with continual action are even as good as rotten.  

**Pandar**  
Therefore let's have fresh ones, whate'er we pay for  
them. If there be not a conscience to be used in  
every trade, we shall never prosper.  

**Bawd**  
Thou sayest true: 'tis not our bringing up of poor  
bastards,--as, I think, I have brought up some eleven--  

**BOULT**  
Ay, to eleven; and brought them down again. But  
shall I search the market?  

**Bawd**  
What else, man? The stuff we have, a strong wind  
will blow it to pieces, they are so pitifully sodden.  

**Pandar**  
Thou sayest true; they're too unwholesome, o'  
conscience. The poor Transylvanian is dead, that  
lay with the little baggage.  

**BOULT**  
Ay, she quickly pooped him; she made him roast-meat  
for worms. But I'll go search the market.  

_Exit_

**Pandar**  
Three or four thousand chequins were as pretty a  
proportion to live quietly, and so give over.  

**Bawd**  
Why to give over, I pray you? is it a shame to get  
when we are old?  

**Pandar**  
O, our credit comes not in like the commodity, nor  
the commodity wages not with the danger: therefore,  
if in our youths we could pick up some pretty  
estate, 'twere not amiss to keep our door hatched.  
Besides, the sore terms we stand upon with the gods  
will be strong with us for giving over.  

**Bawd**  
Come, other sorts offend as well as we.  

**Pandar**  
As well as we! ay, and better too; we offend worse.  
Neither is our profession any trade; it's no  
calling. But here comes Boult.  

_Re-enter BOULT, with the Pirates and MARINA_

**BOULT**  
_[To MARINA]_  
Come your ways. My masters, you say  
she's a virgin?  

**First Pirate**  
O, sir, we doubt it not.  

**BOULT**  
Master, I have gone through for this piece, you see:  
if you like her, so; if not, I have lost my earnest.  

**Bawd**  
Boult, has she any qualities?  

**BOULT**  
She has a good face, speaks well, and has excellent  
good clothes: there's no further necessity of  
qualities can make her be refused.  

**Bawd**  
What's her price, Boult?  

**BOULT**  
I cannot be bated one doit of a thousand pieces.  

**Pandar**  
Well, follow me, my masters, you shall have your  
money presently. Wife, take her in; instruct her  
what she has to do, that she may not be raw in her  
entertainment.  

_Exeunt Pandar and Pirates_

**Bawd**  
Boult, take you the marks of her, the colour of her  
hair, complexion, height, age, with warrant of her  
virginity; and cry 'He that will give most shall  
have her first.' Such a maidenhead were no cheap  
thing, if men were as they have been. Get this done  
as I command you.  

**BOULT**  
Performance shall follow.  

_Exit_

**MARINA**  
Alack that Leonine was so slack, so slow!  
He should have struck, not spoke; or that these pirates,  
Not enough barbarous, had not o'erboard thrown me  
For to seek my mother!  

**Bawd**  
Why lament you, pretty one?  

**MARINA**  
That I am pretty.  

**Bawd**  
Come, the gods have done their part in you.  

**MARINA**  
I accuse them not.  

**Bawd**  
You are light into my hands, where you are like to live.  

**MARINA**  
The more my fault  
To scape his hands where I was like to die.  

**Bawd**  
Ay, and you shall live in pleasure.  

**MARINA**  
No.  

**Bawd**  
Yes, indeed shall you, and taste gentlemen of all  
fashions: you shall fare well; you shall have the  
difference of all complexions. What! do you stop your ears?  

**MARINA**  
Are you a woman?  

**Bawd**  
What would you have me be, an I be not a woman?  

**MARINA**  
An honest woman, or not a woman.  

**Bawd**  
Marry, whip thee, gosling: I think I shall have  
something to do with you. Come, you're a young  
foolish sapling, and must be bowed as I would have  
you.  

**MARINA**  
The gods defend me!  

**Bawd**  
If it please the gods to defend you by men, then men  
must comfort you, men must feed you, men must stir  
you up. Boult's returned.  

_Re-enter BOULT_

Now, sir, hast thou cried her through the market?  

**BOULT**  
I have cried her almost to the number of her hairs;  
I have drawn her picture with my voice.  

**Bawd**  
And I prithee tell me, how dost thou find the  
inclination of the people, especially of the younger sort?  

**BOULT**  
'Faith, they listened to me as they would have  
hearkened to their father's testament. There was a  
Spaniard's mouth so watered, that he went to bed to  
her very description.  

**Bawd**  
We shall have him here to-morrow with his best ruff on.  

**BOULT**  
To-night, to-night. But, mistress, do you know the  
French knight that cowers i' the hams?  

**Bawd**  
Who, Monsieur Veroles?  

**BOULT**  
Ay, he: he offered to cut a caper at the  
proclamation; but he made a groan at it, and swore  
he would see her to-morrow.  

**Bawd**  
Well, well; as for him, he brought his disease  
hither: here he does but repair it. I know he will  
come in our shadow, to scatter his crowns in the  
sun.  

**BOULT**  
Well, if we had of every nation a traveller, we  
should lodge them with this sign.  

**Bawd**  
_[To MARINA]_  
Pray you, come hither awhile. You  
have fortunes coming upon you. Mark me: you must  
seem to do that fearfully which you commit  
willingly, despise profit where you have most gain.  
To weep that you live as ye do makes pity in your  
lovers: seldom but that pity begets you a good  
opinion, and that opinion a mere profit.  

**MARINA**  
I understand you not.  

**BOULT**  
O, take her home, mistress, take her home: these  
blushes of hers must be quenched with some present practise.  

**Bawd**  
Thou sayest true, i' faith, so they must; for your  
bride goes to that with shame which is her way to go  
with warrant.  

**BOULT**  
'Faith, some do, and some do not. But, mistress, if  
I have bargained for the joint,--  

**Bawd**  
Thou mayst cut a morsel off the spit.  

**BOULT**  
I may so.  

**Bawd**  
Who should deny it? Come, young one, I like the  
manner of your garments well.  

**BOULT**  
Ay, by my faith, they shall not be changed yet.  

**Bawd**  
Boult, spend thou that in the town: report what a  
sojourner we have; you'll lose nothing by custom.  
When nature flamed this piece, she meant thee a good  
turn; therefore say what a paragon she is, and thou  
hast the harvest out of thine own report.  

**BOULT**  
I warrant you, mistress, thunder shall not so awake  
the beds of eels as my giving out her beauty stir up  
the lewdly-inclined. I'll bring home some to-night.  

**Bawd**  
Come your ways; follow me.  

**MARINA**  
If fires be hot, knives sharp, or waters deep,  
Untied I still my virgin knot will keep.  
Diana, aid my purpose!  

**Bawd**  
What have we to do with Diana? Pray you, will you go with us?  

_Exeunt_

### SCENE III. Tarsus. A room in CLEON's house.

_Enter CLEON and DIONYZA_

**DIONYZA**  
Why, are you foolish? Can it be undone?  

**CLEON**  
O Dionyza, such a piece of slaughter  
The sun and moon ne'er look'd upon!  

**DIONYZA**  
I think  
You'll turn a child again.  

**CLEON**  
Were I chief lord of all this spacious world,  
I'ld give it to undo the deed. O lady,  
Much less in blood than virtue, yet a princess  
To equal any single crown o' the earth  
I' the justice of compare! O villain Leonine!  
Whom thou hast poison'd too:  
If thou hadst drunk to him, 't had been a kindness  
Becoming well thy fact: what canst thou say  
When noble Pericles shall demand his child?  

**DIONYZA**  
That she is dead. Nurses are not the fates,  
To foster it, nor ever to preserve.  
She died at night; I'll say so. Who can cross it?  
Unless you play the pious innocent,  
And for an honest attribute cry out  
'She died by foul play.'  

**CLEON**  
O, go to. Well, well,  
Of all the faults beneath the heavens, the gods  
Do like this worst.  

**DIONYZA**  
Be one of those that think  
The petty wrens of Tarsus will fly hence,  
And open this to Pericles. I do shame  
To think of what a noble strain you are,  
And of how coward a spirit.  

**CLEON**  
To such proceeding  
Who ever but his approbation added,  
Though not his prime consent, he did not flow  
From honourable sources.  

**DIONYZA**  
Be it so, then:  
Yet none does know, but you, how she came dead,  
Nor none can know, Leonine being gone.  
She did disdain my child, and stood between  
Her and her fortunes: none would look on her,  
But cast their gazes on Marina's face;  
Whilst ours was blurted at and held a malkin  
Not worth the time of day. It pierced me through;  
And though you call my course unnatural,  
You not your child well loving, yet I find  
It greets me as an enterprise of kindness  
Perform'd to your sole daughter.  

**CLEON**  
Heavens forgive it!  

**DIONYZA**  
And as for Pericles,  
What should he say? We wept after her hearse,  
And yet we mourn: her monument  
Is almost finish'd, and her epitaphs  
In glittering golden characters express  
A general praise to her, and care in us  
At whose expense 'tis done.  

**CLEON**  
Thou art like the harpy,  
Which, to betray, dost, with thine angel's face,  
Seize with thine eagle's talons.  

**DIONYZA**  
You are like one that superstitiously  
Doth swear to the gods that winter kills the flies:  
But yet I know you'll do as I advise.  

_Exeunt_

### SCENE IV

_Enter GOWER, before the monument of MARINA at Tarsus_

**GOWER**  
Thus time we waste, and longest leagues make short;  
Sail seas in cockles, have an wish but for't;  
Making, to take your imagination,  
From bourn to bourn, region to region.  
By you being pardon'd, we commit no crime  
To use one language in each several clime  
Where our scenes seem to live. I do beseech you  
To learn of me, who stand i' the gaps to teach you,  
The stages of our story. Pericles  
Is now again thwarting the wayward seas,  
Attended on by many a lord and knight.  
To see his daughter, all his life's delight.  
Old Escanes, whom Helicanus late  
Advanced in time to great and high estate,  
Is left to govern. Bear you it in mind,  
Old Helicanus goes along behind.  
Well-sailing ships and bounteous winds have brought  
This king to Tarsus,--think his pilot thought;  
So with his steerage shall your thoughts grow on,--  
To fetch his daughter home, who first is gone.  
Like motes and shadows see them move awhile;  
Your ears unto your eyes I'll reconcile.  
DUMB SHOW.  

_Enter PERICLES, at one door, with all his train; CLEON and DIONYZA, at the
other. CLEON shows PERICLES the tomb; whereat PERICLES makes lamentation, puts
on sackcloth, and in a mighty passion departs. Then exeunt CLEON and DIONYZA_

See how belief may suffer by foul show!  
This borrow'd passion stands for true old woe;  
And Pericles, in sorrow all devour'd,  
With sighs shot through, and biggest tears  
o'ershower'd,  
Leaves Tarsus and again embarks. He swears  
Never to wash his face, nor cut his hairs:  
He puts on sackcloth, and to sea. He bears  
A tempest, which his mortal vessel tears,  
And yet he rides it out. Now please you wit.  
The epitaph is for Marina writ  
By wicked Dionyza.  

_Reads the inscription on MARINA 's monument_

'The fairest, sweet'st, and best lies here,  
Who wither'd in her spring of year.  
She was of Tyrus the king's daughter,  
On whom foul death hath made this slaughter;  
Marina was she call'd; and at her birth,  
Thetis, being proud, swallow'd some part o' the earth:  
Therefore the earth, fearing to be o'erflow'd,  
Hath Thetis' birth-child on the heavens bestow'd:  
Wherefore she does, and swears she'll never stint,  
Make raging battery upon shores of flint.'  
No visor does become black villany  
So well as soft and tender flattery.  
Let Pericles believe his daughter's dead,  
And bear his courses to be ordered  
By Lady Fortune; while our scene must play  
His daughter's woe and heavy well-a-day  
In her unholy service. Patience, then,  
And think you now are all in Mytilene.  

_Exit_

### SCENE V. Mytilene. A street before the brothel.

_Enter, from the brothel, two Gentlemen_

**First Gentleman**  
Did you ever hear the like?  

**Second Gentleman**  
No, nor never shall do in such a place as this, she  
being once gone.  

**First Gentleman**  
But to have divinity preached there! did you ever  
dream of such a thing?  

**Second Gentleman**  
No, no. Come, I am for no more bawdy-houses:  
shall's go hear the vestals sing?  

**First Gentleman**  
I'll do any thing now that is virtuous; but I  
am out of the road of rutting for ever.  

_Exeunt_

### SCENE VI. The same. A room in the brothel.

_Enter Pandar, Bawd, and BOULT_

**Pandar**  
Well, I had rather than twice the worth of her she  
had ne'er come here.  

**Bawd**  
Fie, fie upon her! she's able to freeze the god  
Priapus, and undo a whole generation. We must  
either get her ravished, or be rid of her. When she  
should do for clients her fitment, and do me the  
kindness of our profession, she has me her quirks,  
her reasons, her master reasons, her prayers, her  
knees; that she would make a puritan of the devil,  
if he should cheapen a kiss of her.  

**BOULT**  
'Faith, I must ravish her, or she'll disfurnish us  
of all our cavaliers, and make our swearers priests.  

**Pandar**  
Now, the pox upon her green-sickness for me!  

**Bawd**  
'Faith, there's no way to be rid on't but by the  
way to the pox. Here comes the Lord Lysimachus disguised.  

**BOULT**  
We should have both lord and lown, if the peevish  
baggage would but give way to customers.  

_Enter LYSIMACHUS_

**LYSIMACHUS**  
How now! How a dozen of virginities?  

**Bawd**  
Now, the gods to-bless your honour!  

**BOULT**  
I am glad to see your honour in good health.  

**LYSIMACHUS**  
You may so; 'tis the better for you that your  
resorters stand upon sound legs. How now!  
wholesome iniquity have you that a man may deal  
withal, and defy the surgeon?  

**Bawd**  
We have here one, sir, if she would--but there never  
came her like in Mytilene.  

**LYSIMACHUS**  
If she'ld do the deed of darkness, thou wouldst say.  

**Bawd**  
Your honour knows what 'tis to say well enough.  

**LYSIMACHUS**  
Well, call forth, call forth.  

**BOULT**  
For flesh and blood, sir, white and red, you shall  
see a rose; and she were a rose indeed, if she had but--  

**LYSIMACHUS**  
What, prithee?  

**BOULT**  
O, sir, I can be modest.  

**LYSIMACHUS**  
That dignifies the renown of a bawd, no less than it  
gives a good report to a number to be chaste.  

_Exit BOULT_

**Bawd**  
Here comes that which grows to the stalk; never  
plucked yet, I can assure you.  

_Re-enter BOULT with MARINA_

Is she not a fair creature?  

**LYSIMACHUS**  
'Faith, she would serve after a long voyage at sea.  
Well, there's for you: leave us.  

**Bawd**  
I beseech your honour, give me leave: a word, and  
I'll have done presently.  

**LYSIMACHUS**  
I beseech you, do.  

**Bawd**  
_[To MARINA]_  
First, I would have you note, this is  
an honourable man.  

**MARINA**  
I desire to find him so, that I may worthily note him.  

**Bawd**  
Next, he's the governor of this country, and a man  
whom I am bound to.  

**MARINA**  
If he govern the country, you are bound to him  
indeed; but how honourable he is in that, I know not.  

**Bawd**  
Pray you, without any more virginal fencing, will  
you use him kindly? He will line your apron with gold.  

**MARINA**  
What he will do graciously, I will thankfully receive.  

**LYSIMACHUS**  
Ha' you done?  

**Bawd**  
My lord, she's not paced yet: you must take some  
pains to work her to your manage. Come, we will  
leave his honour and her together. Go thy ways.  

_Exeunt Bawd, Pandar, and BOULT_

**LYSIMACHUS**  
Now, pretty one, how long have you been at this trade?  

**MARINA**  
What trade, sir?  

**LYSIMACHUS**  
Why, I cannot name't but I shall offend.  

**MARINA**  
I cannot be offended with my trade. Please you to name it.  

**LYSIMACHUS**  
How long have you been of this profession?  

**MARINA**  
E'er since I can remember.  

**LYSIMACHUS**  
Did you go to 't so young? Were you a gamester at  
five or at seven?  

**MARINA**  
Earlier too, sir, if now I be one.  

**LYSIMACHUS**  
Why, the house you dwell in proclaims you to be a  
creature of sale.  

**MARINA**  
Do you know this house to be a place of such resort,  
and will come into 't? I hear say you are of  
honourable parts, and are the governor of this place.  

**LYSIMACHUS**  
Why, hath your principal made known unto you who I am?  

**MARINA**  
Who is my principal?  

**LYSIMACHUS**  
Why, your herb-woman; she that sets seeds and roots  
of shame and iniquity. O, you have heard something  
of my power, and so stand aloof for more serious  
wooing. But I protest to thee, pretty one, my  
authority shall not see thee, or else look friendly  
upon thee. Come, bring me to some private place:  
come, come.  

**MARINA**  
If you were born to honour, show it now;  
If put upon you, make the judgment good  
That thought you worthy of it.  

**LYSIMACHUS**  
How's this? how's this? Some more; be sage.  

**MARINA**  
For me,  
That am a maid, though most ungentle fortune  
Have placed me in this sty, where, since I came,  
Diseases have been sold dearer than physic,  
O, that the gods  
Would set me free from this unhallow'd place,  
Though they did change me to the meanest bird  
That flies i' the purer air!  

**LYSIMACHUS**  
I did not think  
Thou couldst have spoke so well; ne'er dream'd thou couldst.  
Had I brought hither a corrupted mind,  
Thy speech had alter'd it. Hold, here's gold for thee:  
Persever in that clear way thou goest,  
And the gods strengthen thee!  

**MARINA**  
The good gods preserve you!  

**LYSIMACHUS**  
For me, be you thoughten  
That I came with no ill intent; for to me  
The very doors and windows savour vilely.  
Fare thee well. Thou art a piece of virtue, and  
I doubt not but thy training hath been noble.  
Hold, here's more gold for thee.  
A curse upon him, die he like a thief,  
That robs thee of thy goodness! If thou dost  
Hear from me, it shall be for thy good.  

_Re-enter BOULT_

**BOULT**  
I beseech your honour, one piece for me.  

**LYSIMACHUS**  
Avaunt, thou damned door-keeper!  
Your house, but for this virgin that doth prop it,  
Would sink and overwhelm you. Away!  

_Exit_

**BOULT**  
How's this? We must take another course with you.  
If your peevish chastity, which is not worth a  
breakfast in the cheapest country under the cope,  
shall undo a whole household, let me be gelded like  
a spaniel. Come your ways.  

**MARINA**  
Whither would you have me?  

**BOULT**  
I must have your maidenhead taken off, or the common  
hangman shall execute it. Come your ways. We'll  
have no more gentlemen driven away. Come your ways, I say.  

_Re-enter Bawd_

**Bawd**  
How now! what's the matter?  

**BOULT**  
Worse and worse, mistress; she has here spoken holy  
words to the Lord Lysimachus.  

**Bawd**  
O abominable!  

**BOULT**  
She makes our profession as it were to stink afore  
the face of the gods.  

**Bawd**  
Marry, hang her up for ever!  

**BOULT**  
The nobleman would have dealt with her like a  
nobleman, and she sent him away as cold as a  
snowball; saying his prayers too.  

**Bawd**  
Boult, take her away; use her at thy pleasure:  
crack the glass of her virginity, and make the rest malleable.  

**BOULT**  
An if she were a thornier piece of ground than she  
is, she shall be ploughed.  

**MARINA**  
Hark, hark, you gods!  

**Bawd**  
She conjures: away with her! Would she had never  
come within my doors! Marry, hang you! She's born  
to undo us. Will you not go the way of women-kind?  
Marry, come up, my dish of chastity with rosemary and bays!  

_Exit_

**BOULT**  
Come, mistress; come your ways with me.  

**MARINA**  
Whither wilt thou have me?  

**BOULT**  
To take from you the jewel you hold so dear.  

**MARINA**  
Prithee, tell me one thing first.  

**BOULT**  
Come now, your one thing.  

**MARINA**  
What canst thou wish thine enemy to be?  

**BOULT**  
Why, I could wish him to be my master, or rather, my mistress.  

**MARINA**  
Neither of these are so bad as thou art,  
Since they do better thee in their command.  
Thou hold'st a place, for which the pained'st fiend  
Of hell would not in reputation change:  
Thou art the damned doorkeeper to every  
Coistrel that comes inquiring for his Tib;  
To the choleric fisting of every rogue  
Thy ear is liable; thy food is such  
As hath been belch'd on by infected lungs.  

**BOULT**  
What would you have me do? go to the wars, would  
you? where a man may serve seven years for the loss  
of a leg, and have not money enough in the end to  
buy him a wooden one?  

**MARINA**  
Do any thing but this thou doest. Empty  
OLD receptacles, or common shores, of filth;  
Serve by indenture to the common hangman:  
Any of these ways are yet better than this;  
For what thou professest, a baboon, could he speak,  
Would own a name too dear. O, that the gods  
Would safely deliver me from this place!  
Here, here's gold for thee.  
If that thy master would gain by thee,  
Proclaim that I can sing, weave, sew, and dance,  
With other virtues, which I'll keep from boast:  
And I will undertake all these to teach.  
I doubt not but this populous city will  
Yield many scholars.  

**BOULT**  
But can you teach all this you speak of?  

**MARINA**  
Prove that I cannot, take me home again,  
And prostitute me to the basest groom  
That doth frequent your house.  

**BOULT**  
Well, I will see what I can do for thee: if I can  
place thee, I will.  

**MARINA**  
But amongst honest women.  

**BOULT**  
'Faith, my acquaintance lies little amongst them.  
But since my master and mistress have bought you,  
there's no going but by their consent: therefore I  
will make them acquainted with your purpose, and I  
doubt not but I shall find them tractable enough.  
Come, I'll do for thee what I can; come your ways.  

_Exeunt_

# ACT V

### PROLOGUE

_Enter GOWER_

**GOWER**  
Marina thus the brothel 'scapes, and chances  
Into an honest house, our story says.  
She sings like one immortal, and she dances  
As goddess-like to her admired lays;  
Deep clerks she dumbs; and with her needle composes  
Nature's own shape, of bud, bird, branch, or berry,  
That even her art sisters the natural roses;  
Her inkle, silk, twin with the rubied cherry:  
That pupils lacks she none of noble race,  
Who pour their bounty on her; and her gain  
She gives the cursed bawd. Here we her place;  
And to her father turn our thoughts again,  
Where we left him, on the sea. We there him lost;  
Whence, driven before the winds, he is arrived  
Here where his daughter dwells; and on this coast  
Suppose him now at anchor. The city strived  
God Neptune's annual feast to keep: from whence  
Lysimachus our Tyrian ship espies,  
His banners sable, trimm'd with rich expense;  
And to him in his barge with fervor hies.  
In your supposing once more put your sight  
Of heavy Pericles; think this his bark:  
Where what is done in action, more, if might,  
Shall be discover'd; please you, sit and hark.  

_Exit_

### SCENE I. On board PERICLES' ship, off Mytilene. A close

pavilion on deck, with a curtain before it; PERICLES  
within it, reclined on a couch. A barge lying  
beside the Tyrian vessel.  

_Enter two Sailors, one belonging to the Tyrian vessel, the other to the
barge; to them HELICANUS_

**Tyrian Sailor**  
_[To the Sailor of Mytilene]_  
Where is lord Helicanus?  
he can resolve you.  
O, here he is.  
Sir, there's a barge put off from Mytilene,  
And in it is Lysimachus the governor,  
Who craves to come aboard. What is your will?  

**HELICANUS**  
That he have his. Call up some gentlemen.  

**Tyrian Sailor**  
Ho, gentlemen! my lord calls.  

_Enter two or three Gentlemen_

**First Gentleman**  
Doth your lordship call?  

**HELICANUS**  
Gentlemen, there's some of worth would come aboard;  
I pray ye, greet them fairly.  

_The Gentlemen and the two Sailors descend, and go on board the barge_

_Enter, from thence, LYSIMACHUS and Lords; with the Gentlemen and the two
Sailors_

**Tyrian Sailor**  
Sir,  
This is the man that can, in aught you would,  
Resolve you.  

**LYSIMACHUS**  
Hail, reverend sir! the gods preserve you!  

**HELICANUS**  
And you, sir, to outlive the age I am,  
And die as I would do.  

**LYSIMACHUS**  
You wish me well.  
Being on shore, honouring of Neptune's triumphs,  
Seeing this goodly vessel ride before us,  
I made to it, to know of whence you are.  

**HELICANUS**  
First, what is your place?  

**LYSIMACHUS**  
I am the governor of this place you lie before.  

**HELICANUS**  
Sir,  
Our vessel is of Tyre, in it the king;  
A man who for this three months hath not spoken  
To any one, nor taken sustenance  
But to prorogue his grief.  

**LYSIMACHUS**  
Upon what ground is his distemperature?  

**HELICANUS**  
'Twould be too tedious to repeat;  
But the main grief springs from the loss  
Of a beloved daughter and a wife.  

**LYSIMACHUS**  
May we not see him?  

**HELICANUS**  
You may;  
But bootless is your sight: he will not speak To any.  

**LYSIMACHUS**  
Yet let me obtain my wish.  

**HELICANUS**  
Behold him.  

_PERICLES discovered_

This was a goodly person,  
Till the disaster that, one mortal night,  
Drove him to this.  

**LYSIMACHUS**  
Sir king, all hail! the gods preserve you!  
Hail, royal sir!  

**HELICANUS**  
It is in vain; he will not speak to you.  

**First Lord**  
Sir,  
We have a maid in Mytilene, I durst wager,  
Would win some words of him.  

**LYSIMACHUS**  
'Tis well bethought.  
She questionless with her sweet harmony  
And other chosen attractions, would allure,  
And make a battery through his deafen'd parts,  
Which now are midway stopp'd:  
She is all happy as the fairest of all,  
And, with her fellow maids is now upon  
The leafy shelter that abuts against  
The island's side.  

_Whispers a Lord, who goes off in the barge of LYSIMACHUS_

**HELICANUS**  
Sure, all's effectless; yet nothing we'll omit  
That bears recovery's name. But, since your kindness  
We have stretch'd thus far, let us beseech you  
That for our gold we may provision have,  
Wherein we are not destitute for want,  
But weary for the staleness.  

**LYSIMACHUS**  
O, sir, a courtesy  
Which if we should deny, the most just gods  
For every graff would send a caterpillar,  
And so afflict our province. Yet once more  
Let me entreat to know at large the cause  
Of your king's sorrow.  

**HELICANUS**  
Sit, sir, I will recount it to you:  
But, see, I am prevented.  

_Re-enter, from the barge, Lord, with MARINA, and a young Lady_

**LYSIMACHUS**  
O, here is  
The lady that I sent for. Welcome, fair one!  
Is't not a goodly presence?  

**HELICANUS**  
She's a gallant lady.  

**LYSIMACHUS**  
She's such a one, that, were I well assured  
Came of a gentle kind and noble stock,  
I'ld wish no better choice, and think me rarely wed.  
Fair one, all goodness that consists in bounty  
Expect even here, where is a kingly patient:  
If that thy prosperous and artificial feat  
Can draw him but to answer thee in aught,  
Thy sacred physic shall receive such pay  
As thy desires can wish.  

**MARINA**  
Sir, I will use  
My utmost skill in his recovery, Provided  
That none but I and my companion maid  
Be suffer'd to come near him.  

**LYSIMACHUS**  
Come, let us leave her;  
And the gods make her prosperous!  

_MARINA sings_

**LYSIMACHUS**  
Mark'd he your music?  

**MARINA**  
No, nor look'd on us.  

**LYSIMACHUS**  
See, she will speak to him.  

**MARINA**  
Hail, sir! my lord, lend ear.  

**PERICLES**  
Hum, ha!  

**MARINA**  
I am a maid,  
My lord, that ne'er before invited eyes,  
But have been gazed on like a comet: she speaks,  
My lord, that, may be, hath endured a grief  
Might equal yours, if both were justly weigh'd.  
Though wayward fortune did malign my state,  
My derivation was from ancestors  
Who stood equivalent with mighty kings:  
But time hath rooted out my parentage,  
And to the world and awkward casualties  
Bound me in servitude.  

_Aside_

I will desist;  
But there is something glows upon my cheek,  
And whispers in mine ear, 'Go not till he speak.'  

**PERICLES**  
My fortunes--parentage--good parentage--  
To equal mine!--was it not thus? what say you?  

**MARINA**  
I said, my lord, if you did know my parentage,  
You would not do me violence.  

**PERICLES**  
I do think so. Pray you, turn your eyes upon me.  
You are like something that--What country-woman?  
Here of these shores?  

**MARINA**  
No, nor of any shores:  
Yet I was mortally brought forth, and am  
No other than I appear.  

**PERICLES**  
I am great with woe, and shall deliver weeping.  
My dearest wife was like this maid, and such a one  
My daughter might have been: my queen's square brows;  
Her stature to an inch; as wand-like straight;  
As silver-voiced; her eyes as jewel-like  
And cased as richly; in pace another Juno;  
Who starves the ears she feeds, and makes them hungry,  
The more she gives them speech. Where do you live?  

**MARINA**  
Where I am but a stranger: from the deck  
You may discern the place.  

**PERICLES**  
Where were you bred?  
And how achieved you these endowments, which  
You make more rich to owe?  

**MARINA**  
If I should tell my history, it would seem  
Like lies disdain'd in the reporting.  

**PERICLES**  
Prithee, speak:  
Falseness cannot come from thee; for thou look'st  
Modest as Justice, and thou seem'st a palace  
For the crown'd Truth to dwell in: I will  
believe thee,  
And make my senses credit thy relation  
To points that seem impossible; for thou look'st  
Like one I loved indeed. What were thy friends?  
Didst thou not say, when I did push thee back--  
Which was when I perceived thee--that thou camest  
From good descending?  

**MARINA**  
So indeed I did.  

**PERICLES**  
Report thy parentage. I think thou said'st  
Thou hadst been toss'd from wrong to injury,  
And that thou thought'st thy griefs might equal mine,  
If both were open'd.  

**MARINA**  
Some such thing  
I said, and said no more but what my thoughts  
Did warrant me was likely.  

**PERICLES**  
Tell thy story;  
If thine consider'd prove the thousandth part  
Of my endurance, thou art a man, and I  
Have suffer'd like a girl: yet thou dost look  
Like Patience gazing on kings' graves, and smiling  
Extremity out of act. What were thy friends?  
How lost thou them? Thy name, my most kind virgin?  
Recount, I do beseech thee: come, sit by me.  

**MARINA**  
My name is Marina.  

**PERICLES**  
O, I am mock'd,  
And thou by some incensed god sent hither  
To make the world to laugh at me.  

**MARINA**  
Patience, good sir,  
Or here I'll cease.  

**PERICLES**  
Nay, I'll be patient.  
Thou little know'st how thou dost startle me,  
To call thyself Marina.  

**MARINA**  
The name  
Was given me by one that had some power,  
My father, and a king.  

**PERICLES**  
How! a king's daughter?  
And call'd Marina?  

**MARINA**  
You said you would believe me;  
But, not to be a troubler of your peace,  
I will end here.  

**PERICLES**  
But are you flesh and blood?  
Have you a working pulse? and are no fairy?  
Motion! Well; speak on. Where were you born?  
And wherefore call'd Marina?  

**MARINA**  
Call'd Marina  
For I was born at sea.  

**PERICLES**  
At sea! what mother?  

**MARINA**  
My mother was the daughter of a king;  
Who died the minute I was born,  
As my good nurse Lychorida hath oft  
Deliver'd weeping.  

**PERICLES**  
O, stop there a little!  

_Aside_

This is the rarest dream that e'er dull sleep  
Did mock sad fools withal: this cannot be:  
My daughter's buried. Well: where were you bred?  
I'll hear you more, to the bottom of your story,  
And never interrupt you.  

**MARINA**  
You scorn: believe me, 'twere best I did give o'er.  

**PERICLES**  
I will believe you by the syllable  
Of what you shall deliver. Yet, give me leave:  
How came you in these parts? where were you bred?  

**MARINA**  
The king my father did in Tarsus leave me;  
Till cruel Cleon, with his wicked wife,  
Did seek to murder me: and having woo'd  
A villain to attempt it, who having drawn to do't,  
A crew of pirates came and rescued me;  
Brought me to Mytilene. But, good sir,  
Whither will you have me? Why do you weep?  
It may be,  
You think me an impostor: no, good faith;  
I am the daughter to King Pericles,  
If good King Pericles be.  

**PERICLES**  
Ho, Helicanus!  

**HELICANUS**  
Calls my lord?  

**PERICLES**  
Thou art a grave and noble counsellor,  
Most wise in general: tell me, if thou canst,  
What this maid is, or what is like to be,  
That thus hath made me weep?  

**HELICANUS**  
I know not; but  
Here is the regent, sir, of Mytilene  
Speaks nobly of her.  

**LYSIMACHUS**  
She would never tell  
Her parentage; being demanded that,  
She would sit still and weep.  

**PERICLES**  
O Helicanus, strike me, honour'd sir;  
Give me a gash, put me to present pain;  
Lest this great sea of joys rushing upon me  
O'erbear the shores of my mortality,  
And drown me with their sweetness. O, come hither,  
Thou that beget'st him that did thee beget;  
Thou that wast born at sea, buried at Tarsus,  
And found at sea again! O Helicanus,  
Down on thy knees, thank the holy gods as loud  
As thunder threatens us: this is Marina.  
What was thy mother's name? tell me but that,  
For truth can never be confirm'd enough,  
Though doubts did ever sleep.  

**MARINA**  
First, sir, I pray,  
What is your title?  

**PERICLES**  
I am Pericles of Tyre: but tell me now  
My drown'd queen's name, as in the rest you said  
Thou hast been godlike perfect,  
The heir of kingdoms and another like  
To Pericles thy father.  

**MARINA**  
Is it no more to be your daughter than  
To say my mother's name was Thaisa?  
Thaisa was my mother, who did end  
The minute I began.  

**PERICLES**  
Now, blessing on thee! rise; thou art my child.  
Give me fresh garments. Mine own, Helicanus;  
She is not dead at Tarsus, as she should have been,  
By savage Cleon: she shall tell thee all;  
When thou shalt kneel, and justify in knowledge  
She is thy very princess. Who is this?  

**HELICANUS**  
Sir, 'tis the governor of Mytilene,  
Who, hearing of your melancholy state,  
Did come to see you.  

**PERICLES**  
I embrace you.  
Give me my robes. I am wild in my beholding.  
O heavens bless my girl! But, hark, what music?  
Tell Helicanus, my Marina, tell him  
O'er, point by point, for yet he seems to doubt,  
How sure you are my daughter. But, what music?  

**HELICANUS**  
My lord, I hear none.  

**PERICLES**  
None!  
The music of the spheres! List, my Marina.  

**LYSIMACHUS**  
It is not good to cross him; give him way.  

**PERICLES**  
Rarest sounds! Do ye not hear?  

**LYSIMACHUS**  
My lord, I hear.  

_Music_

**PERICLES**  
Most heavenly music!  
It nips me unto listening, and thick slumber  
Hangs upon mine eyes: let me rest.  

_Sleeps_

**LYSIMACHUS**  
A pillow for his head:  
So, leave him all. Well, my companion friends,  
If this but answer to my just belief,  
I'll well remember you.  

_Exeunt all but PERICLES_

_DIANA appears to PERICLES as in a vision_

**DIANA**  
My temple stands in Ephesus: hie thee thither,  
And do upon mine altar sacrifice.  
There, when my maiden priests are met together,  
Before the people all,  
Reveal how thou at sea didst lose thy wife:  
To mourn thy crosses, with thy daughter's, call  
And give them repetition to the life.  
Or perform my bidding, or thou livest in woe;  
Do it, and happy; by my silver bow!  
Awake, and tell thy dream.  

_Disappears_

**PERICLES**  
Celestial Dian, goddess argentine,  
I will obey thee. Helicanus!  

_Re-enter HELICANUS, LYSIMACHUS, and MARINA_

**HELICANUS**  
Sir?  

**PERICLES**  
My purpose was for Tarsus, there to strike  
The inhospitable Cleon; but I am  
For other service first: toward Ephesus  
Turn our blown sails; eftsoons I'll tell thee why.  

_To LYSIMACHUS_

Shall we refresh us, sir, upon your shore,  
And give you gold for such provision  
As our intents will need?  

**LYSIMACHUS**  
Sir,  
With all my heart; and, when you come ashore,  
I have another suit.  

**PERICLES**  
You shall prevail,  
Were it to woo my daughter; for it seems  
You have been noble towards her.  

**LYSIMACHUS**  
Sir, lend me your arm.  

**PERICLES**  
Come, my Marina.  

_Exeunt_

### SCENE II

_Enter GOWER, before the temple of DIANA at Ephesus_

**GOWER**  
Now our sands are almost run;  
More a little, and then dumb.  
This, my last boon, give me,  
For such kindness must relieve me,  
That you aptly will suppose  
What pageantry, what feats, what shows,  
What minstrelsy, and pretty din,  
The regent made in Mytilene  
To greet the king. So he thrived,  
That he is promised to be wived  
To fair Marina; but in no wise  
Till he had done his sacrifice,  
As Dian bade: whereto being bound,  
The interim, pray you, all confound.  
In feather'd briefness sails are fill'd,  
And wishes fall out as they're will'd.  
At Ephesus, the temple see,  
Our king and all his company.  
That he can hither come so soon,  
Is by your fancy's thankful doom.  

_Exit_

### SCENE III. The temple of Diana at Ephesus; THAISA standing

near the altar, as high priestess; a number of  
Virgins on each side; CERIMON and other Inhabitants  
of Ephesus attending.  

_Enter PERICLES, with his train; LYSIMACHUS, HELICANUS, MARINA, and a Lady_

**PERICLES**  
Hail, Dian! to perform thy just command,  
I here confess myself the king of Tyre;  
Who, frighted from my country, did wed  
At Pentapolis the fair Thaisa.  
At sea in childbed died she, but brought forth  
A maid-child call'd Marina; who, O goddess,  
Wears yet thy silver livery. She at Tarsus  
Was nursed with Cleon; who at fourteen years  
He sought to murder: but her better stars  
Brought her to Mytilene; 'gainst whose shore  
Riding, her fortunes brought the maid aboard us,  
Where, by her own most clear remembrance, she  
Made known herself my daughter.  

**THAISA**  
Voice and favour!  
You are, you are--O royal Pericles!  

_Faints_

**PERICLES**  
What means the nun? she dies! help, gentlemen!  

**CERIMON**  
Noble sir,  
If you have told Diana's altar true,  
This is your wife.  

**PERICLES**  
Reverend appearer, no;  
I threw her overboard with these very arms.  

**CERIMON**  
Upon this coast, I warrant you.  

**PERICLES**  
'Tis most certain.  

**CERIMON**  
Look to the lady; O, she's but o'erjoy'd.  
Early in blustering morn this lady was  
Thrown upon this shore. I oped the coffin,  
Found there rich jewels; recover'd her, and placed her  
Here in Diana's temple.  

**PERICLES**  
May we see them?  

**CERIMON**  
Great sir, they shall be brought you to my house,  
Whither I invite you. Look, Thaisa is recovered.  

**THAISA**  
O, let me look!  
If he be none of mine, my sanctity  
Will to my sense bend no licentious ear,  
But curb it, spite of seeing. O, my lord,  
Are you not Pericles? Like him you spake,  
Like him you are: did you not name a tempest,  
A birth, and death?  

**PERICLES**  
The voice of dead Thaisa!  

**THAISA**  
That Thaisa am I, supposed dead  
And drown'd.  

**PERICLES**  
Immortal Dian!  

**THAISA**  
Now I know you better.  
When we with tears parted Pentapolis,  
The king my father gave you such a ring.  

_Shows a ring_

**PERICLES**  
This, this: no more, you gods! your present kindness  
Makes my past miseries sports: you shall do well,  
That on the touching of her lips I may  
Melt and no more be seen. O, come, be buried  
A second time within these arms.  

**MARINA**  
My heart  
Leaps to be gone into my mother's bosom.  

_Kneels to THAISA_

**PERICLES**  
Look, who kneels here! Flesh of thy flesh, Thaisa;  
Thy burden at the sea, and call'd Marina  
For she was yielded there.  

**THAISA**  
Blest, and mine own!  

**HELICANUS**  
Hail, madam, and my queen!  

**THAISA**  
I know you not.  

**PERICLES**  
You have heard me say, when I did fly from Tyre,  
I left behind an ancient substitute:  
Can you remember what I call'd the man?  
I have named him oft.  

**THAISA**  
'Twas Helicanus then.  

**PERICLES**  
Still confirmation:  
Embrace him, dear Thaisa; this is he.  
Now do I long to hear how you were found;  
How possibly preserved; and who to thank,  
Besides the gods, for this great miracle.  

**THAISA**  
Lord Cerimon, my lord; this man,  
Through whom the gods have shown their power; that can  
From first to last resolve you.  

**PERICLES**  
Reverend sir,  
The gods can have no mortal officer  
More like a god than you. Will you deliver  
How this dead queen re-lives?  

**CERIMON**  
I will, my lord.  
Beseech you, first go with me to my house,  
Where shall be shown you all was found with her;  
How she came placed here in the temple;  
No needful thing omitted.  

**PERICLES**  
Pure Dian, bless thee for thy vision! I  
Will offer night-oblations to thee. Thaisa,  
This prince, the fair-betrothed of your daughter,  
Shall marry her at Pentapolis. And now,  
This ornament  
Makes me look dismal will I clip to form;  
And what this fourteen years no razor touch'd,  
To grace thy marriage-day, I'll beautify.  

**THAISA**  
Lord Cerimon hath letters of good credit, sir,  
My father's dead.  

**PERICLES**  
Heavens make a star of him! Yet there, my queen,  
We'll celebrate their nuptials, and ourselves  
Will in that kingdom spend our following days:  
Our son and daughter shall in Tyrus reign.  
Lord Cerimon, we do our longing stay  
To hear the rest untold: sir, lead's the way.  

_Exeunt_

# EPILOGUE

_Enter GOWER_

**GOWER**  
In Antiochus and his daughter you have heard  
Of monstrous lust the due and just reward:  
In Pericles, his queen and daughter, seen,  
Although assail'd with fortune fierce and keen,  
Virtue preserved from fell destruction's blast,  
Led on by heaven, and crown'd with joy at last:  
In Helicanus may you well descry  
A figure of truth, of faith, of loyalty:  
In reverend Cerimon there well appears  
The worth that learned charity aye wears:  
For wicked Cleon and his wife, when fame  
Had spread their cursed deed, and honour'd name  
Of Pericles, to rage the city turn,  
That him and his they in his palace burn;  
The gods for murder seemed so content  
To punish them; although not done, but meant.  
So, on your patience evermore attending,  
New joy wait on you! Here our play has ending.  

_Exit_
